package com.gct.edge.portal.config;

import com.alibaba.cloud.nacos.NacosDiscoveryProperties;
import com.alibaba.cloud.nacos.ribbon.NacosServer;
import com.alibaba.nacos.api.exception.NacosException;
import com.alibaba.nacos.api.naming.NamingService;
import com.alibaba.nacos.api.naming.pojo.Instance;
import com.gct.common.util.StringUtil;
import com.gct.edge.portal.feign.ActuatorClientWrapper;
import com.netflix.client.config.IClientConfig;
import com.netflix.loadbalancer.AbstractLoadBalancerRule;
import com.netflix.loadbalancer.BaseLoadBalancer;
import com.netflix.loadbalancer.ILoadBalancer;
import com.netflix.loadbalancer.Server;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Configuration;

import java.util.List;

/**
 * dec:
 * <p>
 * HashLoadBalanceRule
 * <p>
 * 为edge-actuator服务实现的简单hash取模，暂不需要改一致hash
 *
 * </p>
 *
 * @author lloyd
 * @version 1.0.1
 * @since 2021/11/18 上午9:22
 */
@Slf4j
@Configuration
public class HashLoadBalanceRule extends AbstractLoadBalancerRule {
    @Autowired
    private NacosDiscoveryProperties nacosDiscoveryProperties;

    private IClientConfig config;

    @Override
    public void initWithNiwsConfig(IClientConfig iClientConfig) {
        config = iClientConfig;
    }

    @Override
    public Server choose(Object o) {
        String lbKey = ActuatorClientWrapper.lbKey.get();
        ILoadBalancer loadBalancer = this.getLoadBalancer();
        BaseLoadBalancer baseLoadBalancer = (BaseLoadBalancer) loadBalancer;
        //获取要请求的微服务名称
        String name = baseLoadBalancer.getName();
        //获取服务发现的相关API
        NamingService namingService = nacosDiscoveryProperties.namingServiceInstance();
        try {
            List<Instance> list = namingService.getAllInstances(name, nacosDiscoveryProperties.getGroup());

            if (StringUtil.isBlankOrEmpty(lbKey)) {
                log.error("HashLoadBalance:Not found lbKey,please set module key before access {} server.", name);
                return null;
            }
            if (list.isEmpty())return null;
            Instance instance = list.get(lbKey.hashCode() % list.size());
            return new NacosServer(instance);
        } catch (NacosException e) {
            log.info("HashLoadBalance:not found correct server={},by lbKey={},cause:{}", name, lbKey, e.getMessage());
            return null;
        }
    }
}
