package com.gct.edge.portal.config;

import com.gct.edge.portal.job.AutoInitModuleSpaceJob;
import org.quartz.*;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.util.Date;

/**
 * class name: ModuleLoadBalance
 *
 * @author lloyd
 * @version 1.0
 * @since 2021/5/21 上午10:21
 */
@Configuration
@ConditionalOnProperty(prefix = "spring.gct.edge.portal.lb", name = "enabled", havingValue = "true")
public class ModuleLoadBalance {

    private String jobName = "JOB_AUTO_INIT_MODULE";
    private String jobGroup = "PORTAL_GROUP";

    @Bean
    public JobDetail jobDetailAutoInitModuleSpaceJob() {
        return JobBuilder.newJob(AutoInitModuleSpaceJob.class)
                .withIdentity(jobName, jobGroup)
                .storeDurably()
                .build();
    }

    @Bean
    public Trigger triggerAutoInitModuleSpaceJob() {

        SimpleScheduleBuilder scheduleBuilder = SimpleScheduleBuilder.simpleSchedule()
                .withIntervalInSeconds(30)
                .repeatForever();

        return TriggerBuilder.newTrigger()
                .forJob(jobName, jobGroup)
                .startAt(new Date())
                .withSchedule(scheduleBuilder).build();
    }
}
