package com.gct.edge.portal.constant;

import com.gct.common.util.StringUtil;
import com.gct.edge.portal.job.TimingSummaryJob;
import org.quartz.*;
import org.springframework.scheduling.quartz.QuartzJobBean;

import java.util.Date;
import java.util.Objects;

/**
 * dec: JobConstant
 *
 * @author lloyd
 * @version 1.0
 * @since 2021/12/11 下午3:27
 */
public enum JobConstant {

    GROUP_PORTAL,
    JOB_SYNC_MODULE_CONFIG,
    JOB_LOAD_DATA,
    JOB_SEND_DOWNLOAD,
    JOB_AOID_DAILY,
    JOB_MEMORY_FREE,
    JOB_GROUP,
    JOB_NAME,
    JOB_CLEAR_DELETED,
    ;


    public static Trigger buildTrigger(int interval, boolean repeatable, Date startDateTime, boolean rightNow, String jobGroup, String jobName) {
        if (StringUtil.isBlankOrEmpty(jobGroup) || StringUtil.isBlankOrEmpty(jobName))
            throw new RuntimeException("JobGroup or JobName is null.");
        if (interval <= 0) throw new RuntimeException("Interval is invalid with value:" + interval);
        SimpleScheduleBuilder schedule = SimpleScheduleBuilder.simpleSchedule()
                .withIntervalInSeconds(interval);
        if (repeatable) schedule.repeatForever();


        TriggerBuilder<Trigger> trigger = TriggerBuilder.newTrigger()
                .forJob(jobName, jobGroup);
        if (rightNow) trigger.startNow();
        else {
            if (Objects.isNull(startDateTime)) startDateTime = new Date(new Date().getTime() + 5 * 1000);
            trigger.startAt(startDateTime);
        }
        return trigger.withSchedule(schedule).build();
    }

    public static JobDetail buildJobDetail(Class<? extends QuartzJobBean> jobClass, String jobGroup, String jobName) {
        return JobBuilder.newJob(jobClass)
                .withIdentity(jobName, jobGroup)
                .usingJobData(JOB_GROUP.name(), jobGroup)
                .usingJobData(JOB_NAME.name(), jobName)
                .storeDurably()
                .build();
    }
}
