package com.gct.edge.portal.controller;


import com.gct.common.core.result.CodeMsgEnum;
import com.gct.common.core.result.Result;
import com.gct.edge.portal.entity.EdgeGroupInfo;
import com.gct.edge.portal.service.EdgeGroupInfoService;
import com.gct.edge.portal.service.EdgeModuleConfigInfoService;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.yaml.snakeyaml.util.UriEncoder;

import java.util.List;

/**
 * <p>
 *  前端控制器
 * </p>
 *
 * @author lloyd
 * @since 2021-10-26
 */
@RestController
@RequestMapping("/edgeGroupInfo")
public class EdgeGroupInfoController {

    @Autowired
    EdgeGroupInfoService edgeGroupInfoService;

    @PreAuthorize("hasAuthority('group:read')")
    @ApiOperation(value = "selectOneById(根据id查询分组信息)", notes = "分组数据")
    @GetMapping("/selectOneById")
    public Result selectOneById(@RequestParam("id") @ApiParam("输入分组id") int id) {
        return Result.create(CodeMsgEnum.SUCCESS,edgeGroupInfoService.getById(id));
    }


    @PreAuthorize("hasAuthority('group:write')")
    @ApiOperation(value = "addEdgeGroupInfo(添加分组信息)", notes = "添加分组信息")
    @PostMapping("/addEdgeGroupInfo")
    public Result addEdgeGroupInfo(@RequestBody EdgeGroupInfo edgeGroupInfo){
        return edgeGroupInfoService.addEdgeGroupInfo(edgeGroupInfo);
    }

    @PreAuthorize("hasAuthority('group:write')")
    @ApiOperation(value = "updateEdgeGroupInfo(修改分组信息)", notes = "修改分组信息")
    @PostMapping("/updateEdgeGroupInfo")
    public Result updateEdgeGroupInfo(@RequestBody EdgeGroupInfo edgeGroupInfo){
        return edgeGroupInfoService.updateEdgeGroupInfo(edgeGroupInfo);
    }

    @PreAuthorize("hasAuthority('group:write')")
    @ApiOperation(value = "deleteEdgeGroupInfo(删除分组信息)", notes = "删除分组信息")
    @PostMapping("/deleteEdgeGroupInfo")
    public Result deleteEdgeGroupInfo(@RequestBody List<Integer> ids ){
        boolean removeByIds = edgeGroupInfoService.removeByIds(ids);
        return  removeByIds?Result.create(CodeMsgEnum.DELETE_SUCCESS):Result.create(CodeMsgEnum.DELETE_FAIL);
    }



    @PreAuthorize("hasAuthority('group:read')")
    @ApiOperation(value = "findAllEdgeGroupInfo(根据参数条件查询分组属性数据--分页查询)", notes = "根据参数条件查询分组属性数据")
    @GetMapping("/findAllEdgeGroupInfo")
    public Result findAllEdgeGroupInfo(
            @ApiParam(name = "pageNum",value = "当前页",required = true) @RequestParam("pageNum") Integer pageNum,
            @ApiParam(name = "pageSize",value = "页大小",required = true) @RequestParam("pageSize") Integer pageSize,
            @ApiParam(name = "group_name",value = "group_name") @RequestParam(value = "group_name",required = false) String group_name
    ){
        return edgeGroupInfoService.findAllEdgeGroupInfo(pageNum,pageSize,group_name);
    }

    @PreAuthorize("hasAuthority('group:write')")
    @ApiOperation(value = "addSonEdgeGroupInfo(添加子节点)", notes = "添加子节点")
    @GetMapping("/addSonEdgeGroupInfo")
    public Result addSonEdgeGroupInfo(
            @RequestParam("groupName") @ApiParam("输入分组名称") String groupName,
            @RequestParam("remark") @ApiParam("输入备注") String remark,
            @RequestParam("parentId") @ApiParam("输入父级id") int parentId
    ){
        return edgeGroupInfoService.addSonEdgeGroupInfo(groupName,remark,parentId);
    }

    @PreAuthorize("hasAuthority('group:read')")
    @ApiOperation(value = "树形结构", notes = "树形结构查询")
    @GetMapping("/tree")
    public Result findTree(){
        return edgeGroupInfoService.findTree();
    }

    @PreAuthorize("hasAuthority('group:read')")
    @ApiOperation(value = "列表", notes = "所有分组列表")
    @GetMapping("/list")
    public Result findList(){
        return edgeGroupInfoService.findList();
    }
}

