package com.gct.edge.portal.controller;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.gct.common.core.result.Result;
import com.gct.common.util.DateTimeUtil;
import com.gct.edge.base.util.RSAUtil;
import com.gct.edge.portal.entity.EdgeModuleAuthority;
import com.gct.edge.portal.service.EdgeModuleAuthorityService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.URLEncoder;
import java.time.ZoneOffset;
import java.util.Arrays;
import java.util.Objects;


/**
 * <p>
 *  前端控制器
 * </p>
 *
 * @author lloyd
 * @since 2021-11-01
 */
@RestController
@RequestMapping("/edgeModuleAuthority")
public class EdgeModuleAuthorityController {

    @Autowired
    EdgeModuleAuthorityService edgeModuleAuthorityService;

    @PreAuthorize("hasAuthority('rights:read')")
    @GetMapping("/getModuleAuthorityPage")
    public Result getModuleAuthorityPage(@RequestParam Integer currentPage,@RequestParam Integer pageSize){
        return Result.ok(edgeModuleAuthorityService.getModuleAuthority(currentPage,pageSize));
    }

    @PreAuthorize("hasAuthority('rights:read')")
    @GetMapping("/getModuleNotAuthority")
    public Result getModuleNotAuthority(){
        return Result.ok(edgeModuleAuthorityService.getModuleNotAuthority());
    }

    @PreAuthorize("hasAuthority('rights:apply')")
    @GetMapping("/addModuleAuthority")
    public Result addModuleAuthority(@RequestParam String moduleKey,@RequestParam String macAddress,
                                     @RequestParam String ethernet,@RequestParam String endDate){
        return Result.ok(edgeModuleAuthorityService.addModuleAuthority(moduleKey,macAddress,ethernet,endDate));
    }

    @PreAuthorize("hasAuthority('rights:approve')")
    @GetMapping("/approveActivate")
    public Result approveActivate(@RequestParam String moduleKey){
        return Result.ok(edgeModuleAuthorityService.approveActivate(moduleKey));
    }

    @PreAuthorize("hasAuthority('rights:approve')")
    @GetMapping("/deleteModuleAuthority")
    public Result deleteModuleAuthority(@RequestParam String moduleKey){
        return Result.ok(edgeModuleAuthorityService.deleteModuleAuthority(moduleKey));
    }

    @PreAuthorize("hasAuthority('rights:read')")
    @GetMapping("/downloadActivationCode")
    public void downloadActivationCode(String moduleKey, HttpServletResponse response) throws IOException {
        EdgeModuleAuthority authority = edgeModuleAuthorityService.getOne(
                new QueryWrapper<EdgeModuleAuthority>().eq("module_key", moduleKey));
        if (!Objects.isNull(authority)){
            StringBuilder activateCode = new StringBuilder();
            try(BufferedReader reader = new BufferedReader(new InputStreamReader(
                    this.getClass().getResourceAsStream("/module-activecode-template.txt"))
            )){
                String line;
                while((line=reader.readLine())!=null){
                    activateCode.append(line).append('\n');
                }
            }catch (Exception e){
                e.printStackTrace();
                return;
            }
            activateCode.append("authorize user:").append("\n").append("    ").append(authority.getAuthorizeUser());
            activateCode.append("\nstart time:").append("\n").append("    ").append(DateTimeUtil.formatDateStr(authority.getStartTime()));
            StringBuilder macStr = new StringBuilder();
            Arrays.stream(authority.getMacAddress().split(":")).forEach(macStr::append);
            String key = RSAUtil.encryptShort(Long.toString(authority.getEndTime().toEpochSecond(ZoneOffset.of("+8"))))
                    +"."+RSAUtil.encryptShort(macStr.toString())+"."+RSAUtil.encryptShort(authority.getEthernet());
            activateCode.append("\n").append(key);
            response.reset();
            response.setContentType("application/octet-stream");
            String filename = authority.getModuleKey()+".txt";
            response.addHeader("Content-Disposition", "attachment; filename=" + URLEncoder.encode(filename, "UTF-8"));
            response.getWriter().print(activateCode);
        }
    }
}

