package com.gct.edge.portal.controller;


import com.gct.common.core.result.CodeMsgEnum;
import com.gct.common.core.result.Result;
import com.gct.edge.portal.entity.EdgeModuleConfigInfo;
import com.gct.edge.portal.service.EdgeModuleConfigInfoService;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 前端控制器
 * </p>
 *
 * @author lloyd
 * @since 2021-10-26
 */
@RestController
@RequestMapping("/edgeModuleConfigInfo")
public class EdgeModuleConfigInfoController {

    @Autowired
    EdgeModuleConfigInfoService edgeModuleConfigInfoService;

    @PreAuthorize("hasAuthority('module:read')")
    @GetMapping("/getModuleListByGroupId")
    public Result getModuleListByGroupId(@RequestParam Integer groupId) {
        return Result.ok(edgeModuleConfigInfoService.getModuleListByGroupId(groupId));
    }

    @PreAuthorize("hasAuthority('module:read')")
    @ApiOperation(value = "selectOneModelById(根据id查询模块信息)", notes = "模块数据")
    @GetMapping("/selectOneModelById")
    public Result selectOneModelById(@RequestParam("id") @ApiParam("输入分组id") int id) {
        return Result.create(CodeMsgEnum.SUCCESS, edgeModuleConfigInfoService.getById(id));
    }


    @PreAuthorize("hasAuthority('module:write')")
    @ApiOperation(value = "saveEdgeModuleConfigInfo(添加模块信息)", notes = "添加模块信息")
    @PostMapping("/saveEdgeModuleConfigInfo")
    public Result saveEdgeModuleConfigInfo(@RequestBody EdgeModuleConfigInfo edgeModuleConfigInfo) {
        System.out.println("edgeModuleConfigInfo = " + edgeModuleConfigInfo);
        return edgeModuleConfigInfoService.saveEdgeModuleConfigInfo(edgeModuleConfigInfo);
    }

    @PreAuthorize("hasAuthority('module:write')")
    @ApiOperation(value = "deleteEdgeModuleConfigInfo(删除模块信息)", notes = "删除模块信息")
    @PostMapping("/deleteEdgeModuleConfigInfo")
    public Result deleteEdgeModuleConfigInfo(@RequestBody List<Integer> id) {
        boolean removeByIds = edgeModuleConfigInfoService.logicDelete(id);
        return removeByIds ? Result.create(CodeMsgEnum.DELETE_SUCCESS) : Result.create(CodeMsgEnum.DELETE_FAIL);
    }


    @PreAuthorize("hasAuthority('module:read')")
    @ApiOperation(value = "findAllEdgeModuleConfigInfo(根据参数条件查询模块数据--分页查询)", notes = "根据参数条件查询模块数据")
    @GetMapping("/findAllEdgeModuleConfigInfo")
    public Result findAllEdgeGroupInfo(
            @ApiParam(name = "pageNum", value = "当前页", required = true) @RequestParam("pageNum") Integer pageNum,
            @ApiParam(name = "pageSize", value = "页大小", required = true) @RequestParam("pageSize") Integer pageSize,
            @ApiParam(name = "module_name", value = "module_name") @RequestParam(value = "module_name", required = false) String module_name
    ) {
        return edgeModuleConfigInfoService.findAllEdgeModuleConfigInfo(pageNum, pageSize, module_name);
    }


    @GetMapping("/getEdgeGroupModuleConfigList")
    public Result getEdgeGroupModuleConfigList(){
        //TDDO delete
        return Result.ok(edgeModuleConfigInfoService.getEdgeGroupModuleConfigList());
    }
    @GetMapping("/getEdgeGroupModuleConfigByModuleKey")
    public Result getEdgeGroupModuleConfigByModuleKey(@RequestParam("moduleKey") String moduleKey){
        return  Result.ok(edgeModuleConfigInfoService.getEdgeGroupModuleConfigByModuleKey(moduleKey));
    }


    @GetMapping("/getEdgeModuleConfigInfoByModuleLogicId")
    public Result getEdgeModuleConfigInfoByModuleLogicId(@RequestParam("moduleLogicId") int moduleLogicId){
        return Result.ok(edgeModuleConfigInfoService.getEdgeModuleConfigInfoByModuleLogicId(moduleLogicId));
    }
}

