package com.gct.edge.portal.job;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.gct.common.core.result.Result;
import com.gct.common.util.StringUtil;
import com.gct.edge.base.util.DataBaseUtil;
import com.gct.edge.base.util.DataSourceUtil;
import com.gct.edge.portal.constraint.JobActuatorReference;
import com.gct.edge.portal.entity.EdgeModuleConfigInfo;
import com.gct.edge.portal.entity.EdgeShardDbInfo;
import com.gct.edge.portal.service.EdgeModuleConfigInfoService;
import com.gct.edge.portal.service.EdgeShardDbInfoService;
import lombok.extern.slf4j.Slf4j;
import org.quartz.JobExecutionContext;
import org.quartz.JobExecutionException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.quartz.QuartzJobBean;

import javax.sql.DataSource;
import java.util.List;
import java.util.Objects;

/**
 * class name: ClearDeletedJob
 *
 * @author gxt
 * @version 1.0
 * @since 2022/7/6 下午5:19 周三
 */
@Slf4j
public class ClearDeletedJob extends JobActuatorReference<EdgeModuleConfigInfo> {


    @Autowired
    EdgeModuleConfigInfoService edgeModuleConfigInfoService;
    @Autowired
    EdgeShardDbInfoService edgeShardDbInfoService;

    @Override
    public List<EdgeModuleConfigInfo> external() {
        return edgeModuleConfigInfoService.getBaseMapper().selectList(
                new LambdaQueryWrapper<EdgeModuleConfigInfo>().eq(EdgeModuleConfigInfo::getDeleted, 2));
    }

    @Override
    public Result parallelInternal(EdgeModuleConfigInfo x) {
        if (!StringUtil.isBlankOrEmpty(x.getDbKey()) && Objects.nonNull(x.getDbId())) {
            EdgeShardDbInfo shardDbInfo = edgeShardDbInfoService.getById(x.getDbId());
            DataSource dataSource = DataSourceUtil.createSingleDataSource(shardDbInfo.getJdbcProperty());
            DataBaseUtil util = new DataBaseUtil(dataSource);
            util.setSql("drop schema " + x.getModuleKey() + " cascade").execute();
        }
        edgeModuleConfigInfoService.getBaseMapper().delete(
                new LambdaQueryWrapper<EdgeModuleConfigInfo>().eq(EdgeModuleConfigInfo::getModuleKey, x.getModuleKey()));
        return Result.ok("clear space  success ");
    }
}
