package com.gct.edge.portal.job;

import com.gct.common.core.result.Result;
import com.gct.edge.portal.entity.EdgeModuleConfigInfo;
import com.gct.edge.portal.feign.ActuatorClientWrapper;
import com.gct.edge.portal.service.EdgeModuleConfigInfoService;
import lombok.extern.slf4j.Slf4j;
import org.quartz.JobExecutionContext;
import org.quartz.JobExecutionException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.quartz.QuartzJobBean;

import java.util.List;
import java.util.concurrent.CountDownLatch;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.locks.StampedLock;

/**
 * @author xusirui 2021/11/17
 */
@Slf4j
public class SyncRemoteModuleDataJob extends QuartzJobBean {

    @Autowired
    ActuatorClientWrapper actuatorClient;

    @Autowired
    EdgeModuleConfigInfoService edgeModuleConfigInfoService;

    private static StampedLock lock = new StampedLock();

    @Override
    protected void executeInternal(JobExecutionContext context) throws JobExecutionException {

        long writeLock = 0l;
        try {
            writeLock = lock.tryWriteLock(100, TimeUnit.MILLISECONDS);
            if (writeLock == 0l) return;
        } catch (InterruptedException e) {
            return;
        }
        List<EdgeModuleConfigInfo> list = edgeModuleConfigInfoService.getListByCreatedCondition(new EdgeModuleConfigInfo().setSyncEnabled(1));
        CountDownLatch count = new CountDownLatch(list.size());
        list.stream().parallel().forEach(x -> {
            try {
                Result result = actuatorClient.loadRemoteFile(x.getModuleKey(), x.getIpAddress(), x.getPort(), x.getAuthUser(), x.getAuthPassword(), x.getRemotePath());
                if (result.getStatus() != 1)
                    log.error("Run sync module data failed. module:(id={},moduleKey={},moduleName={}),cause:{}", x.getId(), x.getModuleKey(), x.getModuleName(), result.getMessage());
            } catch (Exception e) {
                log.error("Run sync module data failed. module:(id={},moduleKey={},moduleName={}),cause:{}", x.getId(), x.getModuleKey(), x.getModuleName(), e.getMessage());
            } finally {
                count.countDown();
            }
        });
        try {
            count.await();
        } catch (InterruptedException e) {

        }
        lock.unlockWrite(writeLock);
    }
}
