package com.gct.edge.portal.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gct.common.core.result.Result;
import com.gct.common.util.DateTimeUtil;
import com.gct.edge.base.entity.TableNameEnum;
import com.gct.edge.portal.entity.EdgeModuleConfigInfo;
import com.gct.edge.portal.entity.EdgeSyncConfigMonitor;
import com.gct.edge.portal.feign.ActuatorClientWrapper;
import com.gct.edge.portal.mapper.EdgeSyncConfigMonitorMapper;
import com.gct.edge.portal.service.EdgeAoidSingwellConfigService;
import com.gct.edge.portal.service.EdgeModuleConfigInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
public class EdgeAoidSinglewellConfigServiceImpl extends ServiceImpl<EdgeSyncConfigMonitorMapper, EdgeSyncConfigMonitor> implements EdgeAoidSingwellConfigService {
    @Autowired
    private ActuatorClientWrapper actuatorClientWrapper;

    @Autowired
    private EdgeModuleConfigInfoService edgeModuleConfigInfoService;

    @Override
    public List<Map<String, Object>> getMostNewSingleWellConfig(String moduleKey) {
        Result mostNewSinglewellConfig = actuatorClientWrapper.getMostNewSinglewellConfig(moduleKey);

        List<Object> list = JSON.parseArray(mostNewSinglewellConfig.getData().toString());

        List<Map<String, Object>> listw = new ArrayList<Map<String, Object>>();
        for (Object object : list) {
            Map<String, Object> ageMap = new HashMap<String, Object>();
            Map<String, Object> ret = (Map<String, Object>) object;
            listw.add(ret);
        }
        return listw;

    }

    //修改or保存
    @Override
    public String addSingleWellConfig(JSONObject jsonObject) {
        LocalDateTime now = LocalDateTime.now();
        String s = DateTimeUtil.formatString(now);
        LocalDateTime localDateTime = DateTimeUtil.formatDateTime(s);

        String reSult = "";
        EdgeSyncConfigMonitor edgeSyncConfigMonitor = new EdgeSyncConfigMonitor();
        String moduleKey = jsonObject.getString("moduleKey");
        jsonObject.put("proTime", s);
        QueryWrapper<EdgeSyncConfigMonitor> edgeSyncConfigMonitorQueryWrapper = new QueryWrapper<>();
        edgeSyncConfigMonitorQueryWrapper.eq("module_key", moduleKey)
                .eq("content_type", TableNameEnum.AOID_SINGLEWELL_CONFIG.getKey())
                .last("order by release_version desc limit 1");
        List<EdgeSyncConfigMonitor> edgeSyncConfigMonitors = baseMapper.selectList(edgeSyncConfigMonitorQueryWrapper);
        if (edgeSyncConfigMonitors.size() == 0) {

            Result result = actuatorClientWrapper.addSinglewellConfig(jsonObject);
            if (result.getData().toString().equals("success")) {
                edgeSyncConfigMonitor.setReleaseStatus(0);
                edgeSyncConfigMonitor.setContentType(TableNameEnum.AOID_SINGLEWELL_CONFIG.getKey());
                edgeSyncConfigMonitor.setModuleKey(moduleKey);
                edgeSyncConfigMonitor.setReleaseVersion(localDateTime);
                edgeSyncConfigMonitor.setUpdateTime(localDateTime);
                edgeSyncConfigMonitor.setCreateTime(localDateTime);
                edgeSyncConfigMonitor.setReleaseTime(localDateTime);
                edgeSyncConfigMonitor.setRemark("");
                int insert = baseMapper.insert(edgeSyncConfigMonitor);
                reSult = insert == 1 ? "seccess" : "error";
            }
        } else {
            EdgeSyncConfigMonitor edgeSyncConfigMonitor1 = edgeSyncConfigMonitors.get(0);
            if (edgeSyncConfigMonitor1.getReleaseStatus() == 1) {
                reSult = "版本正在发布，不能修改";
            } else if (edgeSyncConfigMonitor1.getReleaseStatus() == 0) {
                Result result = actuatorClientWrapper.addSinglewellConfig(jsonObject);
                if (result.getStatus() == 1) {
                    List<Map<String, Object>> mostNewSinglewellConfig = getMostNewSingleWellConfig(moduleKey);
                    UpdateWrapper<EdgeSyncConfigMonitor> edgeSyncConfigMonitorUpdateWrapper = new UpdateWrapper<>();
                    String pro_time = mostNewSinglewellConfig.get(0).get("proTime").toString();
                    edgeSyncConfigMonitorUpdateWrapper.eq("module_key", moduleKey)
                            .eq("content_type", TableNameEnum.AOID_SINGLEWELL_CONFIG.getKey())
                            .eq("release_version", edgeSyncConfigMonitor1.getReleaseVersion());
                    edgeSyncConfigMonitor1.setReleaseVersion(DateTimeUtil.formatDateTime(pro_time));
                    int update = baseMapper.update(edgeSyncConfigMonitor1, edgeSyncConfigMonitorUpdateWrapper);
                    reSult = update == 1 ? "seccess" : "error";
                }

            } else {
                Result result = actuatorClientWrapper.addSinglewellConfig(jsonObject);
                if (result.getData().toString().equals("success")) {
                    edgeSyncConfigMonitor.setReleaseStatus(0);
                    edgeSyncConfigMonitor.setContentType(TableNameEnum.AOID_SINGLEWELL_CONFIG.getKey());
                    edgeSyncConfigMonitor.setModuleKey(moduleKey);
                    edgeSyncConfigMonitor.setReleaseVersion(localDateTime);
                    edgeSyncConfigMonitor.setUpdateTime(localDateTime);
                    edgeSyncConfigMonitor.setCreateTime(localDateTime);
                    edgeSyncConfigMonitor.setReleaseTime(localDateTime);
                    edgeSyncConfigMonitor.setRemark("");
                    int insert = baseMapper.insert(edgeSyncConfigMonitor);
                    reSult = insert == 1 ? "seccess" : "error";
                }
            }

        }


        return reSult;
    }

    @Override
    public String publishSingleWellConfigVersion(String moduleKey) {
        UpdateWrapper<EdgeSyncConfigMonitor> edgeSyncConfigMonitorUpdateWrapper = new UpdateWrapper<>();
        edgeSyncConfigMonitorUpdateWrapper.eq("module_key",moduleKey)
                .eq("release_status",0)
                .eq("content_type",TableNameEnum.AOID_SINGLEWELL_CONFIG.getKey())
                .set("release_status",1);
        boolean update = this.update(edgeSyncConfigMonitorUpdateWrapper);
        return  update? "success" : "error";
    }

    @Override
    public String resetSingleWellConfig(String moduleKey) {
        QueryWrapper<EdgeSyncConfigMonitor> edgeSyncConfigMonitorQueryWrapper = new QueryWrapper<>();
        edgeSyncConfigMonitorQueryWrapper
                .eq("module_key",moduleKey)
                .eq("content_type", TableNameEnum.AOID_SINGLEWELL_CONFIG.getKey())
                .last(" order by release_version desc limit 1 ");
        List<EdgeSyncConfigMonitor> edgeSyncConfigMonitors = baseMapper.selectList(edgeSyncConfigMonitorQueryWrapper);
        EdgeSyncConfigMonitor edgeSyncConfigMonitor = edgeSyncConfigMonitors.get(0);
        if (edgeSyncConfigMonitor == null ){
            return "未发布过版本，不能重置";
        }else {
            if(edgeSyncConfigMonitor.getReleaseStatus() == 1 ){
                return "正在发布，不能操作";
            }
            Result result = actuatorClientWrapper.deleteSinglewellConfig(moduleKey, edgeSyncConfigMonitor.getReleaseVersion().toString());

            return result.getData().toString();
        }


    }

    @Override
    public String copySingleWellConfig(JSONObject targetData) {
        List<String> targetDate = (ArrayList<String>) targetData.get("targetData");
        String sourceData = targetData.getString("sourceData");
        ArrayList<String> strings = new ArrayList<>();
        QueryWrapper<EdgeModuleConfigInfo> edgeModuleConfigInfoQueryWrapper = new QueryWrapper<>();
        edgeModuleConfigInfoQueryWrapper.in("module_name", targetDate).select("module_key");
        List<EdgeModuleConfigInfo> edgeModuleConfigInfos = edgeModuleConfigInfoService.getBaseMapper().selectList(edgeModuleConfigInfoQueryWrapper);
        edgeModuleConfigInfos.forEach(item -> strings.add(item.getModuleKey()));
        strings.remove(sourceData);
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("targetModuleKey", strings);
        jsonObject.put("moduleKey", sourceData);
        Result result = actuatorClientWrapper.copySinglewellConfig(jsonObject);
        JSONObject jsonObject1 = JSONObject.parseObject(result.getData().toString());
        int flag = Integer.valueOf(jsonObject1.getString("flag"));
        String copyTime = jsonObject1.getString("copyTime");
        LocalDateTime now = DateTimeUtil.formatDateTime(copyTime);
        if (strings.size() == flag) {
            int flag1 = 0;
            for (int i = 0; i < strings.size(); i++) {
                QueryWrapper<EdgeSyncConfigMonitor> edgeSyncConfigMonitorQueryWrapper = new QueryWrapper<>();
                edgeSyncConfigMonitorQueryWrapper
                        .eq("module_key", strings.get(i))
                        .eq("content_type",TableNameEnum.AOID_SINGLEWELL_CONFIG.getKey())
                        .last("order by release_version desc  limit 1");
                List<EdgeSyncConfigMonitor> edgeSyncConfigMonitors = baseMapper.selectList(edgeSyncConfigMonitorQueryWrapper);
                if (edgeSyncConfigMonitors.size() > 0) {
                    if (edgeSyncConfigMonitors.get(0).getReleaseStatus() == 0) {
                        UpdateWrapper<EdgeSyncConfigMonitor> edgeSyncConfigMonitorUpdateWrapper = new UpdateWrapper<>();
                        edgeSyncConfigMonitorUpdateWrapper
                                .eq("module_key", strings.get(i))
                                .eq("content_type",TableNameEnum.AOID_SINGLEWELL_CONFIG.getKey())
                                .eq("release_version", edgeSyncConfigMonitors.get(0).getReleaseVersion());
                        edgeSyncConfigMonitors.get(0).setReleaseVersion(now);
                        baseMapper.update(edgeSyncConfigMonitors.get(0), edgeSyncConfigMonitorUpdateWrapper);
                        flag1++;
                    } else if (edgeSyncConfigMonitors.get(0).getReleaseStatus() == 1) {
                        flag1++;
                    } else {
                        edgeSyncConfigMonitors.get(0).setReleaseVersion(now);
                        baseMapper.insert(edgeSyncConfigMonitors.get(0));
                        flag1++;
                    }
                } else {
                    EdgeSyncConfigMonitor edgeSyncConfigMonitor = new EdgeSyncConfigMonitor();
                    edgeSyncConfigMonitor.setReleaseStatus(0);
                    edgeSyncConfigMonitor.setContentType(TableNameEnum.AOID_SINGLEWELL_CONFIG.getKey());
                    edgeSyncConfigMonitor.setModuleKey(strings.get(i));
                    edgeSyncConfigMonitor.setReleaseVersion(now);
                    edgeSyncConfigMonitor.setUpdateTime(now);
                    edgeSyncConfigMonitor.setCreateTime(now);
                    edgeSyncConfigMonitor.setReleaseTime(now);
                    edgeSyncConfigMonitor.setRemark("");
                    baseMapper.insert(edgeSyncConfigMonitor);
                    flag1++;
                }
            }
            return flag == flag1 ?"success":"error";
        } else {
            for (int i = 0; i < strings.size(); i++) {
                String s = strings.get(i);
                actuatorClientWrapper.deleteGlobelConfig(sourceData, copyTime);
            }
            return "error";
        }

    }
}
