package com.gct.edge.portal.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.gct.common.util.DateTimeUtil;
import com.gct.edge.portal.entity.EdgeModuleAuthority;
import com.gct.edge.portal.entity.EdgeModuleConfigInfo;
import com.gct.edge.portal.mapper.EdgeModuleAuthorityMapper;
import com.gct.edge.portal.service.EdgeModuleAuthorityService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gct.edge.portal.service.EdgeModuleConfigInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;
import java.util.Objects;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author lloyd
 * @since 2021-11-01
 */
@Service
public class EdgeModuleAuthorityServiceImpl extends ServiceImpl<EdgeModuleAuthorityMapper, EdgeModuleAuthority> implements EdgeModuleAuthorityService {

    @Autowired
    EdgeModuleConfigInfoService edgeModuleConfigInfoService;

    @Override
    public Page<Map<String,Object>> getModuleAuthority(Integer currentPage, Integer pageSize) {
        Page<Map<String, Object>> page = baseMapper.getModuleAuthority(new Page<>(currentPage, pageSize));
        page.getRecords().forEach(x->{
            if(!Objects.isNull(x.get("createTime")))x.put("createTime",x.get("createTime").toString().substring(0,10));
            if(!Objects.isNull(x.get("startTime")))x.put("startTime",x.get("startTime").toString().substring(0,10));
            if(!Objects.isNull(x.get("endTime")))x.put("endTime",x.get("endTime").toString().substring(0,10));
        });
        return page;
    }

    @Override
    public List<Map<String, Object>> getModuleNotAuthority() {
        return baseMapper.getModuleNotAuthority();
    }

    @Override
    public boolean addModuleAuthority(String moduleKey, String macAddress, String ethernet, String endDate) {
        EdgeModuleAuthority authority = new EdgeModuleAuthority();
        EdgeModuleConfigInfo one = edgeModuleConfigInfoService.getOne(new QueryWrapper<EdgeModuleConfigInfo>().eq("module_key", moduleKey));
        if (Objects.isNull(one)){ //申请的模块已经不存在
            return false;
        }
        authority.setModuleKey(moduleKey);
        authority.setEndTime(DateTimeUtil.formatDate(endDate).atTime(23,59,59));
        authority.setCreateTime(LocalDateTime.now());
        authority.setRegister(0);
        authority.setMacAddress(macAddress);
        authority.setEthernet(ethernet);
        authority.setCreateUser(SecurityContextHolder.getContext().getAuthentication().getName());
        return this.saveOrUpdate(authority,new QueryWrapper<EdgeModuleAuthority>().eq("module_key",moduleKey));
    }

    @Override
    public boolean approveActivate(String moduleKey) {

        EdgeModuleAuthority authority = baseMapper.selectOne(new QueryWrapper<EdgeModuleAuthority>().eq("module_key", moduleKey));
        authority.setAuthorizeUser(SecurityContextHolder.getContext().getAuthentication().getName());
        authority.setRegister(1);
        authority.setStartTime(LocalDateTime.now());
        return baseMapper.update(authority,
                new UpdateWrapper<EdgeModuleAuthority>()
                        .eq("module_key",moduleKey)
        )>0;
    }


    @Override
    public boolean deleteModuleAuthority(String moduleKey) {
        return this.remove(new QueryWrapper<EdgeModuleAuthority>().eq("module_key",moduleKey));
    }
}
