package com.gct.edge.portal.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fasterxml.jackson.databind.JsonNode;
import com.gct.common.core.result.CodeMsg;
import com.gct.common.core.result.CodeMsgEnum;
import com.gct.common.core.result.Result;
import com.gct.common.util.StringUtil;
import com.gct.edge.portal.entity.EdgeGroupInfo;
import com.gct.edge.portal.entity.EdgeModuleConfigInfo;
import com.gct.edge.portal.entity.EdgeModuleConfigInfoMetric;
import com.gct.edge.portal.mapper.EdgeModuleConfigInfoMapper;
import com.gct.edge.portal.service.EdgeGroupInfoService;
import com.gct.edge.portal.service.EdgeModuleConfigInfoService;
import com.google.common.collect.Lists;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.xml.bind.annotation.W3CDomHandler;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.*;
import java.util.concurrent.ThreadLocalRandom;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author lloyd
 * @since 2021-10-26
 */
@Service
public class EdgeModuleConfigInfoServiceImpl extends ServiceImpl<EdgeModuleConfigInfoMapper, EdgeModuleConfigInfo> implements EdgeModuleConfigInfoService {

    @Autowired
    EdgeModuleConfigInfoMapper mapper;
    @Autowired
    EdgeGroupInfoService edgeGroupInfoService;

    @Override
    public List<EdgeModuleConfigInfo> getListByCreatedCondition(EdgeModuleConfigInfo condition) {
        LambdaQueryWrapper<EdgeModuleConfigInfo> wrapper = new LambdaQueryWrapper<>();

//        if (!StringUtil.isBlankOrEmpty(condition.getModuleKey()))
//            wrapper.eq(EdgeModuleConfigInfo::getModuleKey, condition.getModuleKey());
        if (Objects.nonNull(condition.getIsLoaded()) && condition.getIsLoaded() > 0)
            wrapper.eq(EdgeModuleConfigInfo::getIsLoaded, condition.getIsLoaded());
        if (Objects.nonNull(condition.getLastTableCreatedTime()))
            wrapper.or().lt(EdgeModuleConfigInfo::getLastTableCreatedTime, condition.getLastTableCreatedTime());
        if (Objects.nonNull(condition.getSyncEnabled()))
            wrapper.eq(EdgeModuleConfigInfo::getSyncEnabled, condition.getSyncEnabled());
        return this.baseMapper.selectList(wrapper);
    }

    @Override
    public List<EdgeModuleConfigInfoMetric> getCountGroupByDBKey(EdgeModuleConfigInfo condition) {

        QueryWrapper<EdgeModuleConfigInfo> wrapper = new QueryWrapper<>();
        if (condition.getIsLoaded() > 0)
            wrapper.eq("is_loaded", condition.getIsLoaded());
        else wrapper.gt("is_loaded", condition.getIsLoaded());

        wrapper.select("db_key,db_id,count(*)");
        wrapper.groupBy("db_key,db_id");
        List<Map<String, Object>> maps = mapper.selectMaps(wrapper);
        if (maps.isEmpty()) return Lists.newArrayList();
        List<EdgeModuleConfigInfoMetric> metric = new ArrayList<>();
        for (Map<String, Object> map : maps) {
            EdgeModuleConfigInfoMetric temp = new EdgeModuleConfigInfoMetric();
            temp.setDbKey((String) map.get("db_key"))
                    .setDbId((Integer) map.get("db_id"))
                    .setCount((Long.valueOf(map.get("count").toString())));
            metric.add(temp);
        }
        return metric;
    }

    @Override
    public boolean updateLoadByKey(EdgeModuleConfigInfo condition) {
        LambdaUpdateWrapper<EdgeModuleConfigInfo> wrapper = new LambdaUpdateWrapper<>();
        wrapper.set(EdgeModuleConfigInfo::getIsLoaded, condition.getIsLoaded())
                .set(EdgeModuleConfigInfo::getUpdateTime, condition.getUpdateTime())
                .set(EdgeModuleConfigInfo::getDbKey, condition.getDbKey())
                .set(EdgeModuleConfigInfo::getDbId, condition.getDbId())
                .set(EdgeModuleConfigInfo::getLastTableCreatedTime, condition.getLastTableCreatedTime())
                .eq(EdgeModuleConfigInfo::getModuleKey, condition.getModuleKey());
        int update = this.baseMapper.update(null, wrapper);
        if (update > 0) return true;
        return false;
    }
    @Override
    public List<EdgeModuleConfigInfo> getModuleListByGroupId(Integer groupId) {
        return baseMapper.getModuleListByGroupId(groupId);
    }


    /**
     * 添加模块信息
     *
     * @param info
     * @return
     */
    @Override
    @Transactional
    public Result saveEdgeModuleConfigInfo(EdgeModuleConfigInfo info) {


        info.setCreateTime(LocalDateTime.now());
        int sus = 0;
        if (StringUtil.isBlankOrEmpty(info.getModuleKey())) {
            info.setModuleKey(newModuleKey());
            info.setDeleted(1);
            sus = mapper.insert(info);
        } else {
            sus = mapper.update(null,
                    new LambdaUpdateWrapper<EdgeModuleConfigInfo>()
                            .set(EdgeModuleConfigInfo::getUpdateTime, LocalDateTime.now())
                            .set(EdgeModuleConfigInfo::getWellIdList, info.getWellIdList())
//                            .set(EdgeModuleConfigInfo::getGroupName, info.getGroupName())
                            .set(EdgeModuleConfigInfo::getModuleName, info.getModuleName())
                            .set(EdgeModuleConfigInfo::getModuleLogicId, info.getModuleLogicId())
                            .set(EdgeModuleConfigInfo::getModuleStatus, info.getModuleStatus())
                            .set(EdgeModuleConfigInfo::getRemark, info.getRemark())
                            .set(EdgeModuleConfigInfo::getIpAddress, info.getIpAddress())
                            .set(EdgeModuleConfigInfo::getPort, info.getPort())
                            .set(EdgeModuleConfigInfo::getAuthPassword, info.getAuthPassword())
                            .set(EdgeModuleConfigInfo::getAuthUser, info.getAuthUser())
                            .set(EdgeModuleConfigInfo::getRemotePath, info.getRemotePath())
                            .set(EdgeModuleConfigInfo::getSyncEnabled, info.getSyncEnabled())
                            .set(EdgeModuleConfigInfo::getDeleted,1)
                            .eq(EdgeModuleConfigInfo::getModuleKey, info.getModuleKey())
            );
        }

        return sus == 1 ? Result.ok("保存成功") : Result.error("保存失败");
    }

    private String newModuleKey() {
        try {
            return "module" + (findModuleCount() + 1);
        } catch (Exception e) {
            return "module" + 1;
        }
    }

    /**
     * 查询最新一条model_key的记录
     *
     * @return
     */

    public Integer findModuleCount() {
        return baseMapper.selectOne(new QueryWrapper<EdgeModuleConfigInfo>().select("max(id) id")).getId();
    }

    @Override
    public List<EdgeModuleConfigInfo> getEdgeGroupModuleConfigList() {
        QueryWrapper<EdgeModuleConfigInfo> wrapper = new QueryWrapper<EdgeModuleConfigInfo>()
                .select("module_key,module_name");
        return baseMapper.selectList(wrapper);
    }

    @Override
    public List<EdgeModuleConfigInfo> getEdgeGroupModuleConfigByModuleKey(String moduleKey) {
        QueryWrapper<EdgeModuleConfigInfo> wrapper = new QueryWrapper<EdgeModuleConfigInfo>()
                .eq("module_key",moduleKey)
                .select("module_key,well_id_list");
        return baseMapper.selectList(wrapper);
    }

    @Override
    public List<EdgeModuleConfigInfo> getEdgeModuleConfigInfoByModuleLogicId(int moduleLogicId) {
        QueryWrapper<EdgeModuleConfigInfo> wrapper = new QueryWrapper<EdgeModuleConfigInfo>()
                .eq("module_logic_id",moduleLogicId);
        return baseMapper.selectList(wrapper);
    }

    @Override
    public boolean logicDelete(List<Integer> ids) {
        AtomicInteger atomicInteger = new AtomicInteger();
        ids.forEach(x->{
            EdgeModuleConfigInfo edgeModuleConfigInfo = new EdgeModuleConfigInfo()
                    .setDeleted(2);
            if (baseMapper.update(edgeModuleConfigInfo,new LambdaQueryWrapper<EdgeModuleConfigInfo>()
                    .eq(EdgeModuleConfigInfo::getId, x).eq(EdgeModuleConfigInfo::getDeleted,1))>0) atomicInteger.incrementAndGet();
        });
        return atomicInteger.get() == ids.size();
    }

    /**
     * 模块名称验证
     *
     * @param modelName
     * @return
     */
    public EdgeModuleConfigInfo findModelByName(String modelName) {
        QueryWrapper<EdgeModuleConfigInfo> queryWrapper = new QueryWrapper<>();   //创建查询queryWrapper
        queryWrapper.eq("module_name", modelName);
        return mapper.selectOne(queryWrapper);
    }


    /**
     * 修改分组信息
     *
     * @param edgeModuleConfigInfo
     * @return
     */
    @Override
    public Result updateEdgeModuleConfigInfo(EdgeModuleConfigInfo edgeModuleConfigInfo) {
        LocalDateTime dateTime = LocalDateTime.now();
        edgeModuleConfigInfo.setUpdateTime(dateTime);
        int update = mapper.updateById(edgeModuleConfigInfo);
        return update == 1 ? Result.create(CodeMsgEnum.MODIFY_SUCCESS) : Result.create(CodeMsgEnum.MODIFY_FAIL);
    }

    /**
     * 根据参数条件查询模块数据
     *
     * @param pageNum
     * @param pageSize
     * @param module_name
     * @return
     */
    @Override
    public Result findAllEdgeModuleConfigInfo(Integer pageNum, Integer pageSize, String module_name) {
        Page<EdgeModuleConfigInfo> paramPage = new Page<>(pageNum, pageSize);
        paramPage.offset();

        if (!StringUtil.isBlankOrEmpty(module_name)) module_name += "%";
        IPage<EdgeModuleConfigInfo> page = baseMapper.findAllEdgeModelInfo
                (paramPage, module_name);
        return Result.ok(page);
    }

}
