package com.gct.edge.portal.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gct.common.core.result.Result;
import com.gct.edge.base.util.DataSourceUtil;
import com.gct.edge.portal.entity.EdgeModuleConfigInfo;
import com.gct.edge.portal.entity.EdgeGroupInfo;
import com.gct.edge.portal.entity.EdgeShardDbInfo;
import com.gct.edge.portal.entity.vo.EdgeShardDbVo;
import com.gct.edge.portal.mapper.EdgeModuleConfigInfoMapper;
import com.gct.edge.portal.mapper.EdgeShardDbInfoMapper;
import com.gct.edge.portal.service.EdgeShardDbInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.time.LocalDateTime;
import java.util.*;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.stream.Collectors;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author lloyd
 * @since 2021-10-26
 */
@Service
public class EdgeShardDbInfoServiceImpl extends ServiceImpl<EdgeShardDbInfoMapper, EdgeShardDbInfo> implements EdgeShardDbInfoService {

    @Autowired
    EdgeShardDbInfoMapper edgeShardDbInfoMapper;
    @Autowired
    EdgeModuleConfigInfoMapper edgeModuleConfigInfoMapper;

    @Override
    public String addDBInfo(EdgeShardDbVo edgeShardDbVo) {
        if (StringUtils.isEmpty(edgeShardDbVo)) return "数据源信息不能为空";
        if ( StringUtils.isEmpty(edgeShardDbVo.getAliasName())||StringUtils.isEmpty(edgeShardDbVo.getUserName()) || StringUtils.isEmpty(edgeShardDbVo.getPassWord()) ||
                StringUtils.isEmpty(edgeShardDbVo.getHost()) || StringUtils.isEmpty(edgeShardDbVo.getPort()) || StringUtils.isEmpty(edgeShardDbVo.getDataSourceName()))
            return "数据源信息存在空值";
        edgeShardDbVo.setJdbcUrl("jdbc:postgresql://" + edgeShardDbVo.getHost() + ":" + edgeShardDbVo.getPort() + "/" + edgeShardDbVo.getDataSourceName());
        String jdbcJson = JSON.toJSONString(edgeShardDbVo);
        if (!DataSourceUtil.testDataSourceConfig(jdbcJson)) return "数据库连接失败,请检查配置信息";
        EdgeShardDbInfo edgeShardDbInfo;
        if (DataSourceUtil.testDataSourceConfig(JSON.toJSONString(edgeShardDbVo))) {
            List<EdgeShardDbInfo> edgeShardDbInfos = edgeShardDbInfoMapper.selectList(null);
            int max = 0;
            if (edgeShardDbInfos != null && !edgeShardDbInfos.isEmpty()){
                max = edgeShardDbInfos.stream().mapToInt(x -> Integer.parseInt(x.getDbKey().substring(4, 5))).max().getAsInt();
            }
            edgeShardDbVo.setDbKey("edge"+(max+1));
            jdbcJson = JSON.toJSONString(edgeShardDbVo);
            edgeShardDbInfo = new EdgeShardDbInfo()
                    .setDbKey("edge"+(max+1))
                    .setAliasName(edgeShardDbVo.getAliasName())
                    .setJdbcProperty(jdbcJson)
                    .setRemark(edgeShardDbVo.getRemark())
                    .setCreateTime(LocalDateTime.now());
            if (edgeShardDbInfoMapper.insert(edgeShardDbInfo) > 0) return "数据库连接成功";
            return "数据库连接失败";
        }
        return "";
    }

    @Override
    public List<EdgeShardDbInfo> getAllList() {
        List<EdgeShardDbInfo> mapList = new ArrayList<>();
        List<EdgeShardDbInfo> edgeShardDbInfos = edgeShardDbInfoMapper.selectList(new QueryWrapper<>());
        QueryWrapper<EdgeModuleConfigInfo> wrapper;
        for (EdgeShardDbInfo edgeShardDbInfo : edgeShardDbInfos) {
            wrapper  = new QueryWrapper<EdgeModuleConfigInfo>()
                    .eq("db_key",edgeShardDbInfo.getDbKey())
                    .select("count(1) ,db_key").groupBy("db_key");
            List<Map<String, Object>> mapList1 = edgeModuleConfigInfoMapper.selectMaps(wrapper);
            if (!StringUtils.isEmpty(mapList1) && mapList1.size()>0)
            edgeShardDbInfo.setModuleNum(Integer.valueOf(mapList1.get(0).get("count").toString()));
            mapList.add(edgeShardDbInfo);
        }
        return mapList;
    }

    @Override
    public Map<String, EdgeShardDbInfo> getAllMaps() {
        //过滤掉逻辑删除的
        List<EdgeShardDbInfo> allList = edgeShardDbInfoMapper.selectList(new QueryWrapper<EdgeShardDbInfo>().eq("deleted",1));
        Map<String, EdgeShardDbInfo> res = new HashMap<>();
        if (allList.isEmpty()) return res;
        res = allList.stream().collect(Collectors.toMap(EdgeShardDbInfo::getDbKey, item -> item, (a, b) -> b));
        return res;
    }
    @Override
    public boolean updateDBInfo(EdgeShardDbVo edgeShardDbVo) {
        if (Objects.isNull(edgeShardDbVo)) return false;
        if (StringUtils.isEmpty(edgeShardDbVo.getPoolName())) edgeShardDbVo.setPoolName(edgeShardDbVo.getAliasName());
        EdgeShardDbInfo edgeShardDbInfo = edgeShardDbInfoMapper.selectOne(new QueryWrapper<EdgeShardDbInfo>().eq("db_key", edgeShardDbVo.getDbKey()));
        EdgeShardDbVo edgeShardDbVo1 = JSONObject.parseObject(edgeShardDbInfo.getJdbcProperty(), EdgeShardDbVo.class);
        edgeShardDbVo1.setAliasName(edgeShardDbVo.getAliasName());
        edgeShardDbVo1.setPoolName(edgeShardDbVo.getPoolName());
        edgeShardDbVo1.setAutoCommit(edgeShardDbVo.getAutoCommit());
        edgeShardDbVo1.setConnectionTimeout(edgeShardDbVo.getConnectionTimeout());
        edgeShardDbVo1.setIdleTimeout(edgeShardDbVo.getIdleTimeout());
        edgeShardDbVo1.setMaxLifetime(edgeShardDbVo.getMaxLifetime());
        edgeShardDbVo1.setMaxPoolSize(edgeShardDbVo.getMaxPoolSize());
        edgeShardDbVo1.setMiniMumIdle(edgeShardDbVo.getMiniMumIdle());
        EdgeShardDbInfo edgeShardDbInfo1 = new EdgeShardDbInfo()
                .setJdbcProperty(JSON.toJSONString(edgeShardDbVo1))
                .setAliasName(edgeShardDbVo.getAliasName())
                .setWeight(edgeShardDbVo.getWeight())
                .setRemark(edgeShardDbVo.getRemark())
                .setUpdateTime(LocalDateTime.now());
        return edgeShardDbInfoMapper.update(edgeShardDbInfo1,new QueryWrapper<EdgeShardDbInfo>().eq("db_key",edgeShardDbVo.getDbKey()))>0;
    }

    @Override
    public EdgeShardDbInfo getShardDInfoByDbKey(String dbKey) {
        QueryWrapper<EdgeShardDbInfo> wrapper = new QueryWrapper<EdgeShardDbInfo>()
                .eq("db_key",dbKey);
        return edgeShardDbInfoMapper.selectOne(wrapper);
    }

    @Override
    public boolean updateWeightByDbKey(JSONObject jsonObject) {
        List<Map<String, Object>> list = jsonObject.getObject("list", List.class);
        AtomicInteger atomicInteger = new AtomicInteger(0);
        list.forEach(x->{
            EdgeShardDbInfo shardDbInfo1 = new EdgeShardDbInfo()
                    .setWeight(Integer.valueOf(x.get("weight").toString()))
                    .setUpdateTime(LocalDateTime.now());
            int update = baseMapper.update(shardDbInfo1, new QueryWrapper<EdgeShardDbInfo>()
                    .eq("db_key", x.get("dbKey"))
                    .eq("alias_name", x.get("aliasName")));
            if (update>0)  atomicInteger.incrementAndGet();
        });
        return atomicInteger.get() == list.size();
    }

    /**
     * 所有数据库列表
     * @return
     */
    @Override
    public Result findDbList() {
        QueryWrapper<EdgeShardDbInfo> wrapper = new QueryWrapper<>();
        List<EdgeShardDbInfo> list = baseMapper.selectList(wrapper);
        return Result.ok(list);
    }


}
