package com.gct.edge.portal.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gct.common.core.result.Result;
import com.gct.common.util.DateTimeUtil;
import com.gct.edge.base.entity.TableNameEnum;
import com.gct.edge.portal.entity.EdgeModuleConfigInfo;
import com.gct.edge.portal.entity.EdgeSyncConfigMonitor;
import com.gct.edge.portal.feign.ActuatorClientWrapper;
import com.gct.edge.portal.mapper.EdgeSyncConfigMonitorMapper;
import com.gct.edge.portal.service.EdgeModuleConfigInfoService;
import com.gct.edge.portal.service.EdgeSyncConfigMonitorService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.*;
import java.util.concurrent.CopyOnWriteArrayList;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.stream.Collectors;

/**
 * class name: EdgeReleaseServiceImpl
 *
 * @author gxt
 * @version 1.0
 * @since 2021/12/2 上午11:12 周四
 */
@Service
public class EdgeSyncConfigMonitorServiceImpl extends ServiceImpl<EdgeSyncConfigMonitorMapper, EdgeSyncConfigMonitor> implements EdgeSyncConfigMonitorService {

    @Autowired
    ActuatorClientWrapper actuatorClientWrapper;
    @Autowired
    EdgeModuleConfigInfoService moduleConfigInfoService;

    @Override
    public String addEdgeReleaseWithReleaseStatus(EdgeSyncConfigMonitor edgeRelease, JSONObject aoidConfigData) {
        LocalDateTime now = LocalDateTime.now();
        String s = DateTimeUtil.formatString(now);
        QueryWrapper<EdgeSyncConfigMonitor> wrapper = new QueryWrapper<EdgeSyncConfigMonitor>()
                .eq("module_key", edgeRelease.getModuleKey())
                .eq("content_type", TableNameEnum.AOID_CONFIG_DATA.getKey())
                .last("order by create_time desc  limit 1 ");
        edgeRelease.setReleaseStatus(0);
        edgeRelease.setContentType(TableNameEnum.AOID_CONFIG_DATA.getKey());
        List<EdgeSyncConfigMonitor> edgeReleases = baseMapper.selectList(wrapper);
        if (edgeReleases.isEmpty()) {
            edgeRelease.setReleaseVersion(DateTimeUtil.formatDateTime(s));
            edgeRelease.setUpdateTime(DateTimeUtil.formatDateTime(s));
            if (baseMapper.insert(edgeRelease) > 0) {
                aoidConfigData.put("moduleKey", edgeRelease.getModuleKey());
                aoidConfigData.put("proTime", edgeRelease.getReleaseVersion());
                return addAoidConfigData(aoidConfigData) ? "success" : "error";
            }
        } else {
            //正在发布的状态,无法修改/或增加
            if (edgeReleases.get(0).getReleaseStatus() == 1) {
                return "publishiing";
            }
            //其他状态 都可以增加,且都认为是新增加的
            else if (edgeReleases.get(0).getReleaseStatus() == 0) {
                edgeRelease.setReleaseVersion(edgeReleases.get(0).getReleaseVersion());
                edgeRelease.setUpdateTime(DateTimeUtil.formatDateTime(s));
                /*
                if (baseMapper.insert(edgeRelease) > 0) {*/
                aoidConfigData.put("moduleKey", edgeRelease.getModuleKey());
                aoidConfigData.put("proTime", edgeRelease.getReleaseVersion());
                return addAoidConfigData(aoidConfigData) ? "success" : "error";
                // }
            } else if (edgeReleases.get(0).getReleaseStatus() == 2) {
                edgeRelease.setReleaseVersion(DateTimeUtil.formatDateTime(s));
                edgeRelease.setUpdateTime(DateTimeUtil.formatDateTime(s));
                if (baseMapper.insert(edgeRelease) > 0) {
                    aoidConfigData.put("moduleKey", edgeRelease.getModuleKey());
                    aoidConfigData.put("proTime", edgeRelease.getReleaseVersion());
                    return addAoidConfigData(aoidConfigData) ? "success" : "error";
                }
            }
        }
        return "error";
    }

    private boolean addAoidConfigData(JSONObject jsonObject) {
        Result result = actuatorClientWrapper.addAoidConfigData(jsonObject);
        if (!StringUtils.isEmpty(result)) {
            return (boolean) result.getData();
        }
        return false;
    }

    @Override
    public String editEdgeReleaseConfigMonitorOrSave(List<Map<String, String>> aoidConfigDataList, List<Map<String, String>> wellIdList) {
        int count = 0;
        AtomicInteger syncInsert = new AtomicInteger();
        QueryWrapper<EdgeSyncConfigMonitor> wrapper;
        for (Map<String, String> map : aoidConfigDataList) {
            wrapper = new QueryWrapper<EdgeSyncConfigMonitor>()
                    .eq("module_key", map.get("moduleKey"))
                    .eq("release_version", DateTimeUtil.formatDateTime(map.get("proTime").replace("T", " ")))
                    .last(" order by release_version desc  limit 1");
            List<EdgeSyncConfigMonitor> list = baseMapper.selectList(wrapper);
            if (!list.isEmpty()) {
                if (list.get(0).getReleaseStatus() == 1) return "publishing";
                else if (list.get(0).getReleaseStatus() == 2) {
                    map.put("proTime", DateTimeUtil.formatString(LocalDateTime.now()));
                    EdgeSyncConfigMonitor edgeSyncConfigMonitor = new EdgeSyncConfigMonitor();
                    edgeSyncConfigMonitor.setModuleKey(map.get("moduleKey"));
                    edgeSyncConfigMonitor.setReleaseVersion(DateTimeUtil.formatDateTime(map.get("proTime").replace("T", " ")));
                    edgeSyncConfigMonitor.setReleaseStatus(0);
                    edgeSyncConfigMonitor.setContentType(TableNameEnum.AOID_CONFIG_DATA.getKey());
                    edgeSyncConfigMonitor.setUpdateTime(LocalDateTime.now());
                    if (syncInsert.get() == 1) {
                        JSONObject jsonObject = setAoidConfigDataEntity(map);
                        count += editOrInsertAoidConfigData(wellIdList, jsonObject, 2);
                    } else if (syncInsert.get() != 1) {
                        if (baseMapper.insert(edgeSyncConfigMonitor) > 0) {
                            syncInsert.set(1);
                            JSONObject jsonObject = setAoidConfigDataEntity(map);
                            count += editOrInsertAoidConfigData(wellIdList, jsonObject, 2);
                        }
                    }
                } else if (list.get(0).getReleaseStatus() == 0) {
                    map.put("proTime", DateTimeUtil.formatString(list.get(0).getReleaseVersion()));
                    JSONObject jsonObject = setAoidConfigDataEntity(map);
                    count += editOrInsertAoidConfigData(wellIdList, jsonObject, 0);
                }
            }
        }
        return count == aoidConfigDataList.size() ? "success" : "error";
    }

    private int editOrInsertAoidConfigData(List<Map<String, String>> wellIdList, JSONObject aoidConfigData, int flag) {
        for (Map<String, String> map : wellIdList) {
            if (map.get("wellName").equals(aoidConfigData.getString("jh"))) {
                aoidConfigData.put("jh", map.get("wellId"));
            }
        }
        int count = 0;
        if (flag == 2) {
            Result result = actuatorClientWrapper.addAoidConfigDataWithList(aoidConfigData);
            if (!StringUtils.isEmpty(result)) {
                if ((boolean) result.getData()) {
                    count = 1;
                }
                return count;
            }
        } else if (flag == 0) {
            Result result = actuatorClientWrapper.editAoidConfigData(aoidConfigData);
            if (!StringUtils.isEmpty(result)) {
                if ((boolean) result.getData()) {
                    count = 1;
                }
                return count;
            }
        }
        return count;
    }

    private JSONObject setAoidConfigDataEntity(Map<String, String> map) {
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("moduleKey", map.get("moduleKey"));
        jsonObject.put("proTime", map.get("proTime"));
        jsonObject.put("jh", map.get("jh"));
        jsonObject.put("bj", map.get("bj"));
        jsonObject.put("bs", map.get("bs"));
        jsonObject.put("hsl", map.get("hsl"));
        jsonObject.put("smd", map.get("smd"));
        jsonObject.put("ymd", map.get("ymd"));
        jsonObject.put("qyb", map.get("qyb"));
        jsonObject.put("dym", map.get("dym"));
        jsonObject.put("yy", map.get("yy"));
        jsonObject.put("ty", map.get("ty"));
        jsonObject.put("hy", map.get("hy"));
        jsonObject.put("totalgtnum", map.get("totalgtnum"));
        return jsonObject;
    }

    @Override
    public List<Map<String, String>> getEdgeReleaseConfigMonitorWithModuleKey(String moduleKey) {
        List<Map<String, String>> resList;
        QueryWrapper<EdgeSyncConfigMonitor> wrapper = new QueryWrapper<EdgeSyncConfigMonitor>()
                .eq("module_key", moduleKey)
                .eq("content_type", TableNameEnum.AOID_CONFIG_DATA.getKey())
                .last("order by  release_version desc  limit 1");
        List<EdgeSyncConfigMonitor> list = baseMapper.selectList(wrapper);
        EdgeSyncConfigMonitor edgeSyncConfigMonitor = new EdgeSyncConfigMonitor();
        if (list.isEmpty()) {
            edgeSyncConfigMonitor.setModuleKey(moduleKey);
            edgeSyncConfigMonitor.setReleaseVersion(DateTimeUtil.formatDateTime(DateTimeUtil.formatString(LocalDateTime.now())));
        } else {
            edgeSyncConfigMonitor = list.get(0);
        }
        Result aoidConfigDataList = actuatorClientWrapper.getAoidConfigDataList(edgeSyncConfigMonitor.getModuleKey(), DateTimeUtil.formatString(edgeSyncConfigMonitor.getReleaseVersion()));
        List<EdgeModuleConfigInfo> edgeGroupModuleConfigByModuleKey = moduleConfigInfoService.getEdgeGroupModuleConfigByModuleKey(edgeSyncConfigMonitor.getModuleKey());
        List<Map<String, String>> list2 = JSONObject.parseObject(edgeGroupModuleConfigByModuleKey.get(0).getWellIdList(), List.class);
        resList = JSONObject.parseObject(aoidConfigDataList.getData().toString(), List.class);
        for (Map<String, String> stringStringMap : resList) {
            int j;
            for (j = 0; j < list2.size(); j++) {
                if (stringStringMap.get("jh").equals(list2.get(j).get("wellId"))) {
                    stringStringMap.put("jh", list2.get(j).get("wellName"));
                    break;
                }
            }
            if (j == list2.size()) {
                stringStringMap.put("jh", "未配置");
            }
        }
        return resList;
    }

    @Override
    public boolean deleteEdgeReleaseConfigMonitorWithModuleKey(String moduleKey, String releaseVersion) {
        QueryWrapper<EdgeSyncConfigMonitor> wrapper = new QueryWrapper<EdgeSyncConfigMonitor>()
                .eq("release_status", 0)
                .eq("module_key", moduleKey)
                .eq("content_type", TableNameEnum.AOID_CONFIG_DATA.getKey())
                .eq("release_version", DateTimeUtil.formatDateTime(releaseVersion));
        return baseMapper.delete(wrapper) > 0;
    }

    @Override
    public boolean publishEdgeReleaseConfigMonitorWithModuleKey(String moduleKey, String releaseVersion) {
        QueryWrapper<EdgeSyncConfigMonitor> wrapper = new QueryWrapper<EdgeSyncConfigMonitor>()
                .eq("module_key", moduleKey)
                .eq("release_status", 0)
                .eq("content_type", TableNameEnum.AOID_CONFIG_DATA.getKey())
                .eq("release_version", DateTimeUtil.formatDateTime(releaseVersion));
        LocalDateTime now = LocalDateTime.now();
        String s = DateTimeUtil.formatString(now);
        EdgeSyncConfigMonitor edgeSyncConfigMonitor = new EdgeSyncConfigMonitor()
                .setContentType(TableNameEnum.AOID_CONFIG_DATA.getKey())
                .setReleaseStatus(1)
                .setUpdateTime(DateTimeUtil.formatDateTime(s));
        return baseMapper.update(edgeSyncConfigMonitor, wrapper) > 0;
    }

    @Override
    public Map<String, Object> copyEdgeReleaseConfigMonitorWithModuleKey(Map<String, String> sourceModule, List<String> targetModule) {
        Map<String, Object> resMap = new HashMap<>();
        List<String> copyFaildModuleAndReason = getEdgeReleaseConfigMonitorWithModuleKeyList(targetModule);
        resMap.put("copyFaildModuleAndReason", copyFaildModuleAndReason);
        List<String> collect = targetModule.stream().filter(item -> !copyFaildModuleAndReason.contains(item)).collect(Collectors.toList());
        List<String> checkOfterList = checkDuplicates(collect, sourceModule.get("proTime"));
        if (copyEdgeReleaseConfigMonitor(sourceModule, checkOfterList)) {
            if (copyAoidConfigData(sourceModule, checkOfterList)) resMap.put("isSuccess", true);
        } else {
            resMap.put("isSuccess", false);
        }
        return resMap;
    }

    @Override
    public List<EdgeSyncConfigMonitor> getRelseaseStatusByModuleKey(String moduleKey) {
        QueryWrapper<EdgeSyncConfigMonitor> wrapper = new QueryWrapper<EdgeSyncConfigMonitor>()
                .eq("module_key", moduleKey)
                .eq("content_type", TableNameEnum.AOID_CONFIG_DATA.getKey())
                .last("order by release_version desc limit 1");
        return baseMapper.selectList(wrapper);
    }

    @Override
    public String addCardLibAndModelLib(JSONObject jsonObject) {
        String moduleKey = jsonObject.getString("moduleKey");
        List<Integer> contentType = new ArrayList<>();
        contentType.add(TableNameEnum.AOID_GK_MODEL.getKey());
        contentType.add(TableNameEnum.DGNS_GTCARD_LIB.getKey());
        Map<Integer, Integer> integerIntegerMap = checkCardLibAndModelLibVersion(moduleKey, contentType);
        Integer cardLibStatus;
        Integer modleLibStatus;
        if (!integerIntegerMap.isEmpty()) {
            modleLibStatus = integerIntegerMap.get(TableNameEnum.AOID_GK_MODEL.getKey());
            cardLibStatus = integerIntegerMap.get(TableNameEnum.DGNS_GTCARD_LIB.getKey());
            if (modleLibStatus == 1 && cardLibStatus == 1) {
                return "正在发布,无法增加";
            } else {
                return saveCardLibOrModelLib(jsonObject);
            }
        } else {
            LocalDateTime now = LocalDateTime.now();
            String s = DateTimeUtil.formatString(now);
            // 在发布表中新增一条,然后将新增拿到的版本号 ,添加 card model
            EdgeSyncConfigMonitor cardLibMonitor = new EdgeSyncConfigMonitor();
            cardLibMonitor.setUpdateTime(LocalDateTime.now());
            cardLibMonitor.setModuleKey(moduleKey);
            cardLibMonitor.setReleaseStatus(0);
            cardLibMonitor.setReleaseVersion(DateTimeUtil.formatDateTime(s));
            cardLibMonitor.setContentType(TableNameEnum.DGNS_GTCARD_LIB.getKey());
            EdgeSyncConfigMonitor modelLibMonitor = new EdgeSyncConfigMonitor();
            BeanUtils.copyProperties(cardLibMonitor, modelLibMonitor);
            modelLibMonitor.setContentType(TableNameEnum.AOID_GK_MODEL.getKey());
            List<EdgeSyncConfigMonitor> monitorList = new ArrayList<>();
            monitorList.add(cardLibMonitor);
            monitorList.add(modelLibMonitor);
            if (this.saveOrUpdateBatch(monitorList)) {
                //发布表新增成功
                return saveCardLibOrModelLib(jsonObject);
            }
        }
        return "";
    }

    @Override
    public String editCardLib(List<Map<String, Object>> mapList) {
        String moduleKey = String.valueOf(mapList.get(0).get("moduleKey"));
        QueryWrapper<EdgeSyncConfigMonitor> wrapper = new QueryWrapper<EdgeSyncConfigMonitor>()
                .eq("module_key", moduleKey)
                .eq("content_type", TableNameEnum.DGNS_GTCARD_LIB.getKey());
        List<EdgeSyncConfigMonitor> monitorList = baseMapper.selectList(wrapper);
        if (!monitorList.isEmpty()) {
            if (monitorList.get(0).getReleaseStatus() == 1) {
                return "正在发布,无法修改";
            }
            JSONObject jsonObject = new JSONObject();
            jsonObject.put("moduleKey", moduleKey);
            jsonObject.put("cardLib", mapList);
            if ("true".equals(String.valueOf(actuatorClientWrapper.editCardLib(jsonObject).getData()))) {
                LocalDateTime now = LocalDateTime.now();
                String s = DateTimeUtil.formatString(now);
                EdgeSyncConfigMonitor edgeSyncConfigMonitor = new EdgeSyncConfigMonitor()
                        .setUpdateTime(DateTimeUtil.formatDateTime(s))
                        .setContentType(TableNameEnum.DGNS_GTCARD_LIB.getKey());
                return baseMapper.update(edgeSyncConfigMonitor, new LambdaQueryWrapper<EdgeSyncConfigMonitor>()
                        .eq(EdgeSyncConfigMonitor::getModuleKey, monitorList.get(0).getModuleKey())
                        .eq(EdgeSyncConfigMonitor::getReleaseVersion, monitorList.get(0).getReleaseVersion())
                        .eq(EdgeSyncConfigMonitor::getUpdateTime, monitorList.get(0).getUpdateTime())) > 0 ? "修改成功" : "修改失败";
            }
        }
        return "未找到数据!";
    }

    @Override
    public String publishCardLib(String moduleKey) {
        QueryWrapper<EdgeSyncConfigMonitor> wrapper = new QueryWrapper<EdgeSyncConfigMonitor>()
                .eq("module_key", moduleKey).eq("content_type", TableNameEnum.DGNS_GTCARD_LIB.getKey());
        List<EdgeSyncConfigMonitor> monitorList = baseMapper.selectList(wrapper);
        if (!monitorList.isEmpty()) {
            if (monitorList.get(0).getReleaseStatus() == 1) {
                return "正在发布";
            }
            EdgeSyncConfigMonitor edgeSyncConfigMonitor = new EdgeSyncConfigMonitor();
            edgeSyncConfigMonitor.setContentType(TableNameEnum.DGNS_GTCARD_LIB.getKey());
            edgeSyncConfigMonitor.setReleaseStatus(1);
            return baseMapper.update(edgeSyncConfigMonitor, wrapper) > 0 ? "success" : "error";
        }
        return null;
    }

    @Override
    public Map<String, Object> copyCardLib(String moduleKey, JSONArray targetData) {
        Map<String, Object> copyList = getCopyList(moduleKey, targetData);
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("sourceModule", moduleKey);
        jsonObject.put("targetModule", copyList.get("copyList"));
        Result result = actuatorClientWrapper.copyCardLib(jsonObject);
        Map<String, Object> map = new HashMap<>();
        map.put("publishModule", copyList.get("inPublishModule"));
        map.put("result", result.getData());
        return map;
    }

    @Override
    public String editAoidModelLib(JSONObject jsonObject) {
        String moduleKey = jsonObject.getString("moduleKey");
        QueryWrapper<EdgeSyncConfigMonitor> wrapper = new QueryWrapper<EdgeSyncConfigMonitor>()
                .eq("module_key", moduleKey);
        List<EdgeSyncConfigMonitor> monitorList = baseMapper.selectList(wrapper);
        if (!monitorList.isEmpty()) {
            if (monitorList.get(0).getReleaseStatus() == 1) {
                return "正在发布无法修改";
            }
            if ("true".equals(actuatorClientWrapper.editAoidGKModelLib(jsonObject).getData().toString())) {
                LocalDateTime now = LocalDateTime.now();
                String s = DateTimeUtil.formatString(now);
                EdgeSyncConfigMonitor edgeSyncConfigMonitor = new EdgeSyncConfigMonitor()
                        .setUpdateTime(DateTimeUtil.formatDateTime(s))
                        .setContentType(TableNameEnum.AOID_GK_MODEL.getKey());
                return baseMapper.update(edgeSyncConfigMonitor, new LambdaQueryWrapper<EdgeSyncConfigMonitor>()
                        .eq(EdgeSyncConfigMonitor::getModuleKey, monitorList.get(0).getModuleKey())
                        .eq(EdgeSyncConfigMonitor::getReleaseVersion, monitorList.get(0).getReleaseVersion())
                        .eq(EdgeSyncConfigMonitor::getUpdateTime, monitorList.get(0).getUpdateTime())) > 0 ? "修改成功" : "修改失败";
            }
        }
        return "";
    }

    @Override
    public String publishAoidModelLib(String modulekey) {
        QueryWrapper<EdgeSyncConfigMonitor> wrapper = new QueryWrapper<EdgeSyncConfigMonitor>()
                .eq("module_key", modulekey)
                .eq("content_type", TableNameEnum.AOID_GK_MODEL.getKey());
        List<EdgeSyncConfigMonitor> monitorList = baseMapper.selectList(wrapper);
        if (!monitorList.isEmpty()) {
            if (monitorList.get(0).getReleaseStatus() == 1) {
                return "正在发布";
            }
            EdgeSyncConfigMonitor edgeSyncConfigMonitor = new EdgeSyncConfigMonitor();
            edgeSyncConfigMonitor.setReleaseStatus(1);
            edgeSyncConfigMonitor.setReleaseTime(LocalDateTime.now());
            edgeSyncConfigMonitor.setContentType(TableNameEnum.AOID_GK_MODEL.getKey());
            edgeSyncConfigMonitor.setModuleKey(modulekey);
            return baseMapper.update(edgeSyncConfigMonitor, wrapper) > 0 ? "success" : "error";
        }
        return null;
    }

    @Override
    public Map<String, Object> copyAoidModelLib(String moduleKey, JSONArray targetData) {
        Map<String, Object> copyListmap = getCopyList(moduleKey, targetData);
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("sourceModule", moduleKey);
        jsonObject.put("targetModule", copyListmap.get("copyList"));
        Result result = actuatorClientWrapper.copyAoidGkModelLib(jsonObject);
        Map<String, Object> map = new HashMap<>();
        map.put("publishModule", copyListmap.get("inPublishModule"));
        map.put("result", result.getData());
        return map;
    }

    @Override
    public String deleteCardLib(JSONObject jsonObject) {
        QueryWrapper<EdgeSyncConfigMonitor> wrapper = new QueryWrapper<EdgeSyncConfigMonitor>()
                .eq("module_key", jsonObject.getString("moduleKey"))
                .eq("content_type", TableNameEnum.DGNS_GTCARD_LIB.getKey());
        List<EdgeSyncConfigMonitor> monitorList = baseMapper.selectList(wrapper);
        if (!monitorList.isEmpty()) {
            if (monitorList.get(0).getReleaseStatus() == 1) {
                return "正在发布中,无法删除";
            }
            if ("true".equals(actuatorClientWrapper.deleteCardLib(jsonObject).getData().toString())){
                LocalDateTime now = LocalDateTime.now();
                String s = DateTimeUtil.formatString(now);
                EdgeSyncConfigMonitor edgeSyncConfigMonitor = new EdgeSyncConfigMonitor()
                        .setUpdateTime(DateTimeUtil.formatDateTime(s))
                        .setContentType(TableNameEnum.DGNS_GTCARD_LIB.getKey());
                return baseMapper.update(edgeSyncConfigMonitor,wrapper) > 0 ? "true" :"error";
            }
        }
        return "error";
    }

    @Override
    public String deleteAoidModelLib(JSONObject jsonObject) {
        QueryWrapper<EdgeSyncConfigMonitor> wrapper = new QueryWrapper<EdgeSyncConfigMonitor>()
                .eq("module_key", jsonObject.getString("moduleKey"))
                .eq("content_type", TableNameEnum.AOID_GK_MODEL.getKey());
        List<EdgeSyncConfigMonitor> monitorList = baseMapper.selectList(wrapper);
        if (!monitorList.isEmpty()) {
            if (monitorList.get(0).getReleaseStatus() == 1) {
                return "正在发布,无法删除";
            }
            if ("true".equals(actuatorClientWrapper.deleteAoidGkModelLib(jsonObject).getData().toString())){
                LocalDateTime now = LocalDateTime.now();
                String s = DateTimeUtil.formatString(now);
                EdgeSyncConfigMonitor edgeSyncConfigMonitor = new EdgeSyncConfigMonitor()
                        .setUpdateTime(DateTimeUtil.formatDateTime(s))
                        .setContentType(TableNameEnum.AOID_GK_MODEL.getKey());
                return baseMapper.update(edgeSyncConfigMonitor,wrapper) > 0 ? "true" :"error";
            }
           
        }
        return "error";
    }

    @Override
    public List<Map<String, Object>> getMostNewGtcvrRuntimeConfig(String moduleKey, Integer content_type) {
    /*    if ("".equals(moduleKey)) return null;
        Result mostNewGtcvrRuntimeConfig = actuatorClientWrapper.getMostNewGtcvrRuntimeConfig(moduleKey);
        Map map = JSONObject.parseObject(mostNewGtcvrRuntimeConfig.getData().toString(), Map.class);*/
        List<Map<String, Object>> data = new ArrayList<Map<String, Object>>();
        QueryWrapper<EdgeSyncConfigMonitor> edgeSyncConfigMonitorQueryWrapper = new QueryWrapper<>();
        edgeSyncConfigMonitorQueryWrapper
                .eq("module_key", moduleKey)
                .eq("content_type", content_type)
                .last("order by create_time desc  limit 2");
        List<EdgeSyncConfigMonitor> edgeSyncConfigMonitors = baseMapper.selectList(edgeSyncConfigMonitorQueryWrapper);
        Map<String, Object> hashMap = new HashMap<String, Object>();
        if (edgeSyncConfigMonitors.size() == 0) {
            hashMap.put("releaseTime", "");
            hashMap.put("status", "");
            hashMap.put("lastReleaseTime", "");
            hashMap.put("lastStatus", "");
        } else if (edgeSyncConfigMonitors.size() == 1) {
            hashMap.put("releaseTime", edgeSyncConfigMonitors.get(0).getReleaseVersion().toString().substring(0, 19).replace("T", " "));
            hashMap.put("status", edgeSyncConfigMonitors.get(0).getReleaseStatus() == 0 ? "未发布" : edgeSyncConfigMonitors.get(0).getReleaseStatus() == 1 ? "待发布" : "已发布");
            hashMap.put("lastReleaseTime", "");
            hashMap.put("lastStatus", "");
        } else {
            hashMap.put("releaseTime", edgeSyncConfigMonitors.get(0).getReleaseVersion().toString().substring(0, 19).replace("T", " "));
            hashMap.put("status", edgeSyncConfigMonitors.get(0).getReleaseStatus() == 0 ? "未发布" : edgeSyncConfigMonitors.get(0).getReleaseStatus() == 1 ? "待发布" : "已发布");
            if (hashMap.get("status").equals("已发布")) {
                hashMap.put("lastReleaseTime", "");
                hashMap.put("lastStatus", "");
            } else {
                hashMap.put("lastReleaseTime", edgeSyncConfigMonitors.get(1).getReleaseVersion().toString().substring(0, 19).replace("T", " "));
                hashMap.put("lastStatus", edgeSyncConfigMonitors.get(1).getReleaseStatus() == 0 ? "未发布" : edgeSyncConfigMonitors.get(1).getReleaseStatus() == 1 ? "待发布" : "已发布");
            }

        }
        data.add(hashMap);
        return data;
    }

    @Override
    public String addEdgeReleaseGlobalConfig(JSONObject jsonObject) {
        LocalDateTime now = LocalDateTime.now();

        String s = DateTimeUtil.formatString(now);
        EdgeSyncConfigMonitor edgeSyncConfigMonitor = new EdgeSyncConfigMonitor();
        jsonObject.put("pro_time", s);
        int contentType = Integer.valueOf(jsonObject.getString("flag"));
        QueryWrapper<EdgeSyncConfigMonitor> edgeSyncConfigMonitorQueryWrapper = new QueryWrapper<>();
        edgeSyncConfigMonitorQueryWrapper
                .eq("module_key", jsonObject.getString("moduleKey"))
                .eq("content_type", TableNameEnum.valueOf(contentType).getKey())
                .last("order by release_version desc  limit 1");
        List<EdgeSyncConfigMonitor> edgeSyncConfigMonitors = baseMapper.selectList(edgeSyncConfigMonitorQueryWrapper);
        List<EdgeModuleConfigInfo> moduleKey = moduleConfigInfoService.getEdgeGroupModuleConfigByModuleKey(jsonObject.getString("moduleKey"));
//        List<Map<String, String>> list = JSONObject.parseObject(moduleKey.get(0).getWellIdList(), List.class);
        String resultString = "";
        if (edgeSyncConfigMonitors.size() == 0) {
            jsonObject.put("proTime", s);
            Result result = getInsertMethods(contentType, jsonObject);
            if (result.getStatus() == 1) {
                edgeSyncConfigMonitor.setReleaseStatus(0);
                edgeSyncConfigMonitor.setContentType(TableNameEnum.valueOf(contentType).getKey());
                edgeSyncConfigMonitor.setModuleKey(jsonObject.getString("moduleKey"));
                edgeSyncConfigMonitor.setReleaseVersion(DateTimeUtil.formatDateTime(s));
                edgeSyncConfigMonitor.setUpdateTime(DateTimeUtil.formatDateTime(s));
                edgeSyncConfigMonitor.setCreateTime(DateTimeUtil.formatDateTime(s));
                edgeSyncConfigMonitor.setReleaseTime(DateTimeUtil.formatDateTime(s));
                edgeSyncConfigMonitor.setRemark("");
                baseMapper.insert(edgeSyncConfigMonitor);
            }
            resultString = "success";
        } else {
            if (edgeSyncConfigMonitors.get(0).getReleaseStatus() == 0) {
                LocalDateTime releaseVersion = edgeSyncConfigMonitors.get(0).getReleaseVersion();
                jsonObject.put("proTime", releaseVersion.toString());
                jsonObject.put("status", "update");
                Result result = getInsertMethods(contentType, jsonObject);
                if (result.getStatus() == 1) {
                    UpdateWrapper<EdgeSyncConfigMonitor> edgeSyncConfigMonitorUpdateWrapper = new UpdateWrapper<>();
                    edgeSyncConfigMonitorUpdateWrapper.eq("module_key", edgeSyncConfigMonitors.get(0).getModuleKey())
                            .eq("release_version", edgeSyncConfigMonitors.get(0).getReleaseVersion());
                    edgeSyncConfigMonitors.get(0).setReleaseVersion(releaseVersion);
                    baseMapper.update(edgeSyncConfigMonitors.get(0), edgeSyncConfigMonitorUpdateWrapper);
                }
                resultString = "success";
            } else if (edgeSyncConfigMonitors.get(0).getReleaseStatus() == 1) {
                resultString = "正在发布中稍后再试";
            } else {
                QueryWrapper<EdgeSyncConfigMonitor> edgeSyncConfigMonitorQueryWrapper1 = new QueryWrapper<>();
                edgeSyncConfigMonitorQueryWrapper1.eq("module_key", jsonObject.getString("moduleKey"))
                        .eq("content_type", TableNameEnum.valueOf(contentType).getKey())
                        .eq("release_status",2)
                        .last("order by release_version desc  limit 1");
                List<EdgeSyncConfigMonitor> edgeSyncConfigMonitors1 = baseMapper.selectList(edgeSyncConfigMonitorQueryWrapper1);
                jsonObject.put("releaseVersion",edgeSyncConfigMonitors1.get(0).getReleaseVersion());
                jsonObject.put("proTime",s);
                jsonObject.put("insetCopyList","insetCopyList");
                Result result = getInsertMethods(contentType, jsonObject);
                if (result.getStatus() == 1) {
                    edgeSyncConfigMonitor.setReleaseStatus(0);
                    edgeSyncConfigMonitor.setContentType(TableNameEnum.valueOf(contentType).getKey());
                    edgeSyncConfigMonitor.setModuleKey(jsonObject.getString("moduleKey"));
                    edgeSyncConfigMonitor.setReleaseVersion(DateTimeUtil.formatDateTime(s));
                    edgeSyncConfigMonitor.setUpdateTime(DateTimeUtil.formatDateTime(s));
                    edgeSyncConfigMonitor.setCreateTime(DateTimeUtil.formatDateTime(s));
                    edgeSyncConfigMonitor.setReleaseTime(DateTimeUtil.formatDateTime(s));
                    edgeSyncConfigMonitor.setRemark("");
                    baseMapper.insert(edgeSyncConfigMonitor);
                }
                resultString = "success";
            }

        }


        return resultString;
    }

    @Override
    public String publishGlobalVersion(String moduleKey, Integer flag) {
        QueryWrapper<EdgeSyncConfigMonitor> edgeSyncConfigMonitorQueryWrapper = new QueryWrapper<>();
        edgeSyncConfigMonitorQueryWrapper.eq("module_key", moduleKey)
                .eq("content_type", TableNameEnum.valueOf(flag).getKey())
                .last("order by release_version desc  limit 1");
        List<EdgeSyncConfigMonitor> edgeSyncConfigMonitors = baseMapper.selectList(edgeSyncConfigMonitorQueryWrapper);
        if (edgeSyncConfigMonitors.size() == 0) {
            return "无发布版本";
        } else {
            if (edgeSyncConfigMonitors.get(0).getReleaseStatus() == 1) {
                return "正在发布中，请稍后再试！";
            } else if (edgeSyncConfigMonitors.get(0).getReleaseStatus() == 2) {
                return "已发布过，不能再发布！";
            }
        }

        UpdateWrapper<EdgeSyncConfigMonitor> edgeSyncConfigMonitorUpdateWrapper = new UpdateWrapper<>();
        edgeSyncConfigMonitorUpdateWrapper.eq("module_key", moduleKey)
                .eq("release_status", 0)
                .eq("content_type", TableNameEnum.valueOf(flag).getKey())
                .set("release_status", 1);
        boolean update = this.update(edgeSyncConfigMonitorUpdateWrapper);
        return update ? "success" : "修改失败";
    }

    @Override
    public String copyGlobalConfig(JSONObject targetData) {
        LocalDateTime localDateTime = LocalDateTime.now();
        String s = DateTimeUtil.formatString(localDateTime);
        LocalDateTime now = DateTimeUtil.formatDateTime(s);
        Integer contentType = Integer.valueOf(targetData.getString("flag"));
        List<String> targetDate = (ArrayList<String>) targetData.get("targetData");
        String sourceData = targetData.getString("sourceData");
        ArrayList<String> strings = new ArrayList<>();
        QueryWrapper<EdgeModuleConfigInfo> edgeModuleConfigInfoQueryWrapper = new QueryWrapper<>();
        edgeModuleConfigInfoQueryWrapper.in("module_name", targetDate).select("module_key");
        List<EdgeModuleConfigInfo> edgeModuleConfigInfos = moduleConfigInfoService.getBaseMapper().selectList(edgeModuleConfigInfoQueryWrapper);
        edgeModuleConfigInfos.forEach(item -> strings.add(item.getModuleKey()));
        strings.remove(sourceData);
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("targetModuleKey", strings);
        jsonObject.put("moduleKey", sourceData);

        for (int i = 0; i < strings.size(); i++) {
            JSONObject jo = new JSONObject();
            QueryWrapper<EdgeSyncConfigMonitor> edgeSyncConfigMonitorQueryWrapper = new QueryWrapper<>();
            edgeSyncConfigMonitorQueryWrapper
                    .eq("module_key", strings.get(i))
                    .eq("content_type", TableNameEnum.valueOf(contentType).getKey())
                    .last("order by release_version desc  limit 1");
            List<EdgeSyncConfigMonitor> edgeSyncConfigMonitors = baseMapper.selectList(edgeSyncConfigMonitorQueryWrapper);
            if (edgeSyncConfigMonitors.size() > 0) {
                if (edgeSyncConfigMonitors.get(0).getReleaseStatus() == 0) {
                    jo.put("relsease_version", edgeSyncConfigMonitors.get(0).getReleaseVersion().toString());
                    jo.put("moduleKey", jsonObject.getString("moduleKey"));
                    jo.put("targetModuleKey", strings.get(i));
                    jo.put("status", "update");
                    jo.put("releaseVersion", targetData.getString("releaseVersion"));
                    getCopyMethods(contentType, jo);


                } else if (edgeSyncConfigMonitors.get(0).getReleaseStatus() == 1) {
                } else {
                    jo.put("moduleKey", jsonObject.getString("moduleKey"));
                    jo.put("targetModuleKey", strings.get(i));
                    jo.put("relsease_version", s);
                    jo.put("releaseVersion", targetData.getString("releaseVersion"));
                    getCopyMethods(TableNameEnum.valueOf(contentType).getKey(), jo);
                    EdgeSyncConfigMonitor edgeSyncConfigMonitor = new EdgeSyncConfigMonitor();
                    edgeSyncConfigMonitor.setReleaseStatus(0);
                    edgeSyncConfigMonitor.setContentType(TableNameEnum.valueOf(contentType).getKey());
                    edgeSyncConfigMonitor.setModuleKey(strings.get(i));
                    edgeSyncConfigMonitor.setReleaseVersion(now);
                    edgeSyncConfigMonitor.setUpdateTime(now);
                    edgeSyncConfigMonitor.setCreateTime(now);
                    edgeSyncConfigMonitor.setReleaseTime(now);
                    edgeSyncConfigMonitor.setRemark("");
                    baseMapper.insert(edgeSyncConfigMonitor);
                }
            } else {
                jo.put("moduleKey", jsonObject.getString("moduleKey"));
                jo.put("targetModuleKey", strings.get(i));
                jo.put("relsease_version", s);
                jo.put("releaseVersion", targetData.getString("releaseVersion"));
                getCopyMethods(TableNameEnum.valueOf(contentType).getKey(), jo);
                EdgeSyncConfigMonitor edgeSyncConfigMonitor = new EdgeSyncConfigMonitor();
                edgeSyncConfigMonitor.setReleaseStatus(0);
                edgeSyncConfigMonitor.setContentType(TableNameEnum.valueOf(contentType).getKey());
                edgeSyncConfigMonitor.setModuleKey(strings.get(i));
                edgeSyncConfigMonitor.setReleaseVersion(now);
                edgeSyncConfigMonitor.setUpdateTime(now);
                edgeSyncConfigMonitor.setCreateTime(now);
                edgeSyncConfigMonitor.setReleaseTime(now);
                edgeSyncConfigMonitor.setRemark("");
                baseMapper.insert(edgeSyncConfigMonitor);
            }
        }
        return "";
    }

    @Override
    public String resetGlobalConfig(String moduleKey, Integer flag) {

        QueryWrapper<EdgeSyncConfigMonitor> edgeSyncConfigMonitorQueryWrapper = new QueryWrapper<>();
        edgeSyncConfigMonitorQueryWrapper
                .eq("module_key", moduleKey)
                .eq("content_type", flag)
                .last(" order by release_version desc limit 1 ");
        List<EdgeSyncConfigMonitor> edgeSyncConfigMonitors = baseMapper.selectList(edgeSyncConfigMonitorQueryWrapper);

        if (edgeSyncConfigMonitors.size() == 0) {
            return "未发布过版本，不能重置";
        } else {
            if (edgeSyncConfigMonitors.get(0).getReleaseStatus() == 1) {
                return "正在发布中，不能重置";
            } else if (edgeSyncConfigMonitors.get(0).getReleaseStatus() == 2) {
                return "success";
            }
            int delete = 0;
//            Result result = actuatorClientWrapper.deleteGlobelConfig(moduleKey, edgeSyncConfigMonitor.getReleaseVersion().toString());
            Result result = getResetMethods(flag, moduleKey, edgeSyncConfigMonitors.get(0).getReleaseVersion().format(DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss")));
            if (result.getStatus() == 1) {
                QueryWrapper<EdgeSyncConfigMonitor> queryWrapper = new QueryWrapper<>();
                queryWrapper.eq("module_key", moduleKey).eq("content_type", flag).eq("release_version", edgeSyncConfigMonitors.get(0).getReleaseVersion());
                delete = baseMapper.delete(queryWrapper);
            }
            return delete == 1 ? "success" : "重置失败";
        }
    }

    @Override
    public String getStatus(String moduleKey, Integer flag) {
        QueryWrapper<EdgeSyncConfigMonitor> edgeSyncConfigMonitorQueryWrapper = new QueryWrapper<>();
        edgeSyncConfigMonitorQueryWrapper
                .eq("module_key", moduleKey)
                .eq("content_type", flag)
                .last(" order by release_version desc limit 1 ");
        List<EdgeSyncConfigMonitor> edgeSyncConfigMonitors = baseMapper.selectList(edgeSyncConfigMonitorQueryWrapper);
        String status = "未知";
        if (edgeSyncConfigMonitors.size() > 0) {
            int releaseStatus = edgeSyncConfigMonitors.get(0).getReleaseStatus();
            switch (releaseStatus) {
                case 0:
                    status = "未发布";
                    break;
                case 1:
                    status = "待发布";
                    break;
                case 2:
                    status = "已发布";
                    break;
            }
        }
        return status;
    }

    @Override
    public List<Map<String, Object>> getAoidStaticDataStatus(String moduleKey) {
        return getMostNewGtcvrRuntimeConfig(moduleKey, TableNameEnum.AOID_CONFIG_DATA.getKey());
    }

    @Override
    public String editSingleWellConfig(JSONObject jsonObject) {
        LocalDateTime localDateTime = LocalDateTime.now();
        String s = DateTimeUtil.formatString(localDateTime);
        LocalDateTime now = DateTimeUtil.formatDateTime(s);
        String resultString = "";
        QueryWrapper<EdgeSyncConfigMonitor> queryWrapper = new QueryWrapper<>();
        queryWrapper
                .eq("module_key", jsonObject.getString("moduleKey"))
                .eq("release_version", DateTimeUtil.formatDateTime(jsonObject.getString("proTime")))
                .select("release_status");
        List<EdgeSyncConfigMonitor> edgeSyncConfigMonitors = baseMapper.selectList(queryWrapper);
        EdgeSyncConfigMonitor edgeSyncConfigMonitor = edgeSyncConfigMonitors.get(0);
        if (edgeSyncConfigMonitor.getReleaseStatus() == 2) {
            jsonObject.put("release_status", edgeSyncConfigMonitor.getReleaseStatus());
            jsonObject.put("release_version", s);
            Result result = actuatorClientWrapper.editSingleWellConfig(jsonObject);
            if ("success".equals(result.getData().toString())) {
                edgeSyncConfigMonitor.setReleaseStatus(0);
                edgeSyncConfigMonitor.setContentType(5);
                edgeSyncConfigMonitor.setModuleKey(jsonObject.getString("moduleKey"));
                edgeSyncConfigMonitor.setReleaseVersion(now);
                edgeSyncConfigMonitor.setUpdateTime(now);
                edgeSyncConfigMonitor.setCreateTime(now);
                edgeSyncConfigMonitor.setReleaseTime(now);
                edgeSyncConfigMonitor.setRemark("");
                int insert = baseMapper.insert(edgeSyncConfigMonitor);
                resultString = insert == 1 ? "success" : "error";
            }
        } else if (edgeSyncConfigMonitor.getReleaseStatus() == 1) {
            return "正在发布中，不能修改！";
        } else {
            jsonObject.put("release_status", edgeSyncConfigMonitor.getReleaseStatus());
            Result result = actuatorClientWrapper.editSingleWellConfig(jsonObject);
            resultString = result.getData().toString();
        }
        return resultString;
    }

    @Override
    public String deleteSingleWellConfig(JSONObject jsonObject) {
        LocalDateTime localDateTime = LocalDateTime.now();
        String s = DateTimeUtil.formatString(localDateTime);
        LocalDateTime now = DateTimeUtil.formatDateTime(s);

        String status = this.getStatus(jsonObject.getString("moduleKey"), 5);
        String resultString = "";

        if ("未发布".equals(status)) {
            jsonObject.put("status", 0);
            Result result = actuatorClientWrapper.deleteSingleWellConfig(jsonObject);
            resultString = result.getData().toString();

        } else if ("已发布".equals(status)) {
            jsonObject.put("status", 2);
            jsonObject.put("release_version", s);
            Result result = actuatorClientWrapper.deleteSingleWellConfig(jsonObject);

            if ("success".equals(result.getData().toString())) {
                EdgeSyncConfigMonitor edgeSyncConfigMonitor = new EdgeSyncConfigMonitor();
                edgeSyncConfigMonitor.setReleaseStatus(0);
                edgeSyncConfigMonitor.setContentType(5);
                edgeSyncConfigMonitor.setModuleKey(jsonObject.getString("moduleKey"));
                edgeSyncConfigMonitor.setReleaseVersion(now);
                edgeSyncConfigMonitor.setUpdateTime(now);
                edgeSyncConfigMonitor.setCreateTime(now);
                edgeSyncConfigMonitor.setReleaseTime(now);
                edgeSyncConfigMonitor.setRemark("");
                int insert = baseMapper.insert(edgeSyncConfigMonitor);
                resultString = insert == 1 ? "success" : "error";
            }
        }
        return resultString;
    }

    @Override
    public Map<String, String> getLastUpdateAndReleaseTime(String moduleKey) {
        List<EdgeSyncConfigMonitor> monitorList = baseMapper.selectList(new LambdaQueryWrapper<EdgeSyncConfigMonitor>()
                .eq(EdgeSyncConfigMonitor::getModuleKey, moduleKey)
                .eq(EdgeSyncConfigMonitor::getContentType, TableNameEnum.DGNS_GTCARD_LIB.getKey()));
        Map<String, String> map = new HashMap<>();
        if (!monitorList.isEmpty()) {
            map.put("cardLibLastReleaseTime", DateTimeUtil.formatString(monitorList.get(0).getReleaseTime()));
            map.put("cardLiblastUpdateTime", DateTimeUtil.formatString(monitorList.get(0).getUpdateTime()));
        }
        List<EdgeSyncConfigMonitor> monitorList1 = baseMapper.selectList(new LambdaQueryWrapper<EdgeSyncConfigMonitor>()
                .eq(EdgeSyncConfigMonitor::getModuleKey, moduleKey)
                .eq(EdgeSyncConfigMonitor::getContentType, TableNameEnum.AOID_GK_MODEL.getKey()));
        if (!monitorList1.isEmpty()) {
            map.put("GkModellastReleaseTime", DateTimeUtil.formatString(monitorList1.get(0).getReleaseTime()));
            map.put("GkModellastUpdateTime", DateTimeUtil.formatString(monitorList1.get(0).getUpdateTime()));
        }
        return map;
    }

    private Map<String, Object> getCopyList(String moduleKey, JSONArray targetData) {
        QueryWrapper<EdgeModuleConfigInfo> wrapper = new QueryWrapper<EdgeModuleConfigInfo>()
                .in("module_name", targetData).select("module_key");
        List<EdgeModuleConfigInfo> edgeModuleConfigInfos = moduleConfigInfoService.getBaseMapper().selectList(wrapper);
        List<String> targetList = new ArrayList<>();
        edgeModuleConfigInfos.forEach(item -> targetList.add(item.getModuleKey()));
        List<String> inPublishModule = getEdgeReleaseConfigMonitorWithModuleKeyList(targetList);
        Map<String, Object> resMap = new HashMap<>();
        resMap.put("copyList", targetList.stream().filter(item -> !inPublishModule.contains(item)).collect(Collectors.toList()));
        resMap.put("inPublishModule", inPublishModule);
        return resMap;
    }

    private Map<Integer, Integer> checkCardLibAndModelLibVersion(String moduleKey, List<Integer> contentType) {
        QueryWrapper<EdgeSyncConfigMonitor> wrapper = new QueryWrapper<EdgeSyncConfigMonitor>()
                .eq("module_key", moduleKey).in("content_type", contentType);
        List<EdgeSyncConfigMonitor> list = baseMapper.selectList(wrapper);
        Map<Integer, List<EdgeSyncConfigMonitor>> collect = list.stream().collect(Collectors.groupingBy(EdgeSyncConfigMonitor::getContentType));
        Map<Integer, Integer> resMap = new HashMap<>();
        for (Map.Entry<Integer, List<EdgeSyncConfigMonitor>> integerListEntry : collect.entrySet()) {
            Optional<EdgeSyncConfigMonitor> max = integerListEntry.getValue().stream().max(Comparator.comparing(EdgeSyncConfigMonitor::getReleaseVersion));
            if (max.isPresent()) {
                EdgeSyncConfigMonitor edgeSyncConfigMonitor = max.get();
                resMap.put(edgeSyncConfigMonitor.getContentType(), edgeSyncConfigMonitor.getReleaseStatus());
            }
        }
        return resMap;
    }

    private List<String> getEdgeReleaseConfigMonitorWithModuleKeyList(List<String> moduleKeyList) {
        QueryWrapper<EdgeSyncConfigMonitor> wrapper = new QueryWrapper<EdgeSyncConfigMonitor>()
                .in("module_key", moduleKeyList);
        List<EdgeSyncConfigMonitor> list = baseMapper.selectList(wrapper);
        Map<String, List<EdgeSyncConfigMonitor>> collect = list.stream().collect(Collectors.groupingBy(EdgeSyncConfigMonitor::getModuleKey));
        List<String> resList = new ArrayList<>();
        for (Map.Entry<String, List<EdgeSyncConfigMonitor>> stringListEntry : collect.entrySet()) {
            Optional<EdgeSyncConfigMonitor> max = stringListEntry.getValue().stream().max(Comparator.comparing(EdgeSyncConfigMonitor::getReleaseVersion));
            if (max.isPresent()) {
                EdgeSyncConfigMonitor edgeSyncConfigMonitor = max.get();
                if (edgeSyncConfigMonitor.getReleaseStatus() == 1) {
                    resList.add(stringListEntry.getKey());
                }
            }
        }
        return resList;
    }

    private List<String> checkDuplicates(List<String> moduleList, String protime) {
        QueryWrapper<EdgeSyncConfigMonitor> wrapper = new QueryWrapper<EdgeSyncConfigMonitor>()
                .in("module_key", moduleList)
                .eq("release_version", DateTimeUtil.formatDateTime(protime)).eq("release_status", 0);
        List<EdgeSyncConfigMonitor> list = baseMapper.selectList(wrapper);
        Map<String, List<EdgeSyncConfigMonitor>> collect = list.stream().collect(Collectors.groupingBy(EdgeSyncConfigMonitor::getModuleKey));
        return moduleList.stream().filter(item -> !collect.containsKey(item)).collect(Collectors.toList());
    }

    private boolean copyEdgeReleaseConfigMonitor(Map<String, String> sourceModule, List<String> targetModule) {
        QueryWrapper<EdgeSyncConfigMonitor> wrapper = new QueryWrapper<EdgeSyncConfigMonitor>()
                .eq("module_key", sourceModule.get("moduleKey"))
                .eq("release_version", DateTimeUtil.formatDateTime(sourceModule.get("proTime")))
                .eq("release_status", 2);
        List<EdgeSyncConfigMonitor> list = baseMapper.selectList(wrapper);
        QueryWrapper<EdgeSyncConfigMonitor> wrapper1 = new QueryWrapper<EdgeSyncConfigMonitor>().select("max(id) id ");
        EdgeSyncConfigMonitor edgeSyncConfigMonitor1 = baseMapper.selectOne(wrapper1);
        EdgeSyncConfigMonitor edgeSyncConfigMonitor;
        Collection<EdgeSyncConfigMonitor> edgeSyncConfigMonitors = new CopyOnWriteArrayList<>();
        LocalDateTime now = LocalDateTime.now();
        String nowTime = DateTimeUtil.formatString(now);
        if (!list.isEmpty()) {
            for (EdgeSyncConfigMonitor syncConfigMonitor : list) {
                for (String s : targetModule) {
                    edgeSyncConfigMonitor = new EdgeSyncConfigMonitor();
                    BeanUtils.copyProperties(syncConfigMonitor, edgeSyncConfigMonitor);
                    edgeSyncConfigMonitor.setModuleKey(s);
                    edgeSyncConfigMonitor.setUpdateTime(DateTimeUtil.formatDateTime(nowTime));
                    edgeSyncConfigMonitor.setId(edgeSyncConfigMonitor1.getId() + 1);
                    edgeSyncConfigMonitor.setContentType(3);
                    edgeSyncConfigMonitor.setReleaseStatus(0);
                    edgeSyncConfigMonitors.add(edgeSyncConfigMonitor);
                }
            }
            return this.saveBatch(edgeSyncConfigMonitors);
        }
        return false;
    }

    private boolean copyAoidConfigData(Map<String, String> sourceModule, List<String> targetModule) {
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("sourceModule", sourceModule);
        jsonObject.put("targetModule", targetModule);
        Result result = actuatorClientWrapper.copyAoidConfigData(jsonObject);
        return (boolean) result.getData();
    }

    private String saveCardLibOrModelLib(JSONObject jsonObject) {
        LocalDateTime localDateTime = LocalDateTime.now();
        String s = DateTimeUtil.formatString(localDateTime);
        if (!StringUtils.isEmpty(jsonObject.getString("cardLib")) || !StringUtils.isEmpty(jsonObject.getString("data"))) {
            if ("true".equals(actuatorClientWrapper.saveDgnsCardLib(jsonObject).getData().toString())){
                EdgeSyncConfigMonitor edgeSyncConfigMonitor = new EdgeSyncConfigMonitor()
                        .setUpdateTime(DateTimeUtil.formatDateTime(s))
                        .setContentType(TableNameEnum.DGNS_GTCARD_LIB.getKey());
               return baseMapper.update(edgeSyncConfigMonitor,new LambdaQueryWrapper<EdgeSyncConfigMonitor>()
                        .eq(EdgeSyncConfigMonitor::getModuleKey,jsonObject.getString("moduleKey"))
                        .eq(EdgeSyncConfigMonitor::getContentType,TableNameEnum.DGNS_GTCARD_LIB.getKey())) > 0 ? "true" : "error";
            }
        } else if (!StringUtils.isEmpty(jsonObject.getString("modelLib"))) {
            if ("true".equals(actuatorClientWrapper.saveAoidGkModelLib(jsonObject).getData().toString())){
                EdgeSyncConfigMonitor edgeSyncConfigMonitor = new EdgeSyncConfigMonitor()
                        .setUpdateTime(DateTimeUtil.formatDateTime(s))
                        .setContentType(TableNameEnum.AOID_GK_MODEL.getKey());
                return baseMapper.update(edgeSyncConfigMonitor,new LambdaQueryWrapper<EdgeSyncConfigMonitor>()
                        .eq(EdgeSyncConfigMonitor::getModuleKey,jsonObject.getString("moduleKey"))
                        .eq(EdgeSyncConfigMonitor::getContentType,TableNameEnum.AOID_GK_MODEL.getKey())) > 0 ? "true" : "error";
            }
        }
        return "";
    }

    private Result getInsertMethods(int contentType, JSONObject jsonObject) {
        Result result = null;
        if (contentType == 11) {
            result = actuatorClientWrapper.SaveGtcvrRuntimeConfig(jsonObject);
        } else if (contentType == 8) {
            result = actuatorClientWrapper.addDgnsGtgktype(jsonObject);
        } else if (contentType == 5) {
            result = actuatorClientWrapper.addSinglewellConfig(jsonObject);
        }
        return result;
    }

    private Result getCopyMethods(int contentType, JSONObject jsonObject) {
        Result result = null;
        if (contentType == 11) {
            result = actuatorClientWrapper.copyGlobelConfig(jsonObject);
        } else if (contentType == 8) {
            result = actuatorClientWrapper.copyDgnsGtgktype(jsonObject);
        } else if (contentType == 5) {
            result = actuatorClientWrapper.copySinglewellConfig(jsonObject);
        }
        return result;
    }

    private Result getResetMethods(int contentType, String moduleKey, String proTime) {
        Result result = null;
        if (contentType == 11) {
            result = actuatorClientWrapper.deleteGlobelConfig(moduleKey, proTime);
        } else if (contentType == 8) {
            result = actuatorClientWrapper.deleteDgnsGtgktype(moduleKey, proTime);
        } else if (contentType == 5) {
            result = actuatorClientWrapper.deleteSinglewellConfig(moduleKey, proTime);
        }
        return result;
    }

}
