create table if not exists ${module_key}.yield_real_time${postfix}
            (
                module_key            varchar,
                well_id               varchar   not null,
                well_common_name      varchar,
                pro_time              timestamp not null,
                stroke                double precision,
                frequence             double precision,
                pump_diameter         double precision,
                pump_depth            double precision,
                submergence           double precision,
                nozzle_diameter       double precision,
                rise_load             double precision,
                decline_load          double precision,
                work_diagram          varchar,
                pump_work_diagram     varchar,
                result1               varchar,
                refrence_well_id      varchar,
                refrence_create_time  timestamp,
                liq_prod_daily        double precision,
                oil_prod_daily        double precision,
                gas_prod_daily        double precision,
                result2               varchar,
                pump_efficiency       double precision,
                moisture_content      double precision,
                flag                  double precision,
                expand_coefficient    double precision,
                theory_displacement   double precision,
                left_stroke           double precision,
                right_stroke          double precision,
                actual_stroke         double precision,
                effect_stroke         double precision,
                stroke_loss           double precision,
                outflow_loss          double precision,
                liq_loss              double precision,
                back_press            double precision,
                oil_press             double precision,
                sleeve_press          double precision,
                water_prod_daily      double precision,
                refrence_work_diagram varchar,
                present_time          double precision,
                gas_liq_ratio         double precision,
                effect_stroke_ratio   double precision,
                voltage               double precision,
                ambient_temperature   double precision,
                electricity           double precision,
                signal_strength       double precision,
                device_id             double precision,
                well_name             varchar,
                id                    varchar   not null,
                constraint yield_real_time${postfix}_pk
                    primary key (well_id, pro_time)
            );
            
            comment on column ${module_key}.yield_real_time${postfix}.module_key is '分库分表所需key';
            
            comment on column ${module_key}.yield_real_time${postfix}.well_id is '井号';
            
            comment on column ${module_key}.yield_real_time${postfix}.well_common_name is '井名称';
            
            comment on column ${module_key}.yield_real_time${postfix}.pro_time is '实时时间';
            
            comment on column ${module_key}.yield_real_time${postfix}.stroke is '冲程';
            
            comment on column ${module_key}.yield_real_time${postfix}.frequence is '冲次';
            
            comment on column ${module_key}.yield_real_time${postfix}.pump_diameter is '泵径';
            
            comment on column ${module_key}.yield_real_time${postfix}.pump_depth is '泵深';
            
            comment on column ${module_key}.yield_real_time${postfix}.submergence is '沉没度';
            
            comment on column ${module_key}.yield_real_time${postfix}.nozzle_diameter is '油嘴直径';
            
            comment on column ${module_key}.yield_real_time${postfix}.rise_load is '上行载荷';
            
            comment on column ${module_key}.yield_real_time${postfix}.decline_load is '下行载荷';
            
            comment on column ${module_key}.yield_real_time${postfix}.work_diagram is '示功图';
            
            comment on column ${module_key}.yield_real_time${postfix}.pump_work_diagram is '泵功图';
            
            comment on column ${module_key}.yield_real_time${postfix}.result1 is '一次诊断结果';
            
            comment on column ${module_key}.yield_real_time${postfix}.refrence_well_id is '参考井号';
            
            comment on column ${module_key}.yield_real_time${postfix}.refrence_create_time is '参考创建时间';
            
            comment on column ${module_key}.yield_real_time${postfix}.liq_prod_daily is '日产液';
            
            comment on column ${module_key}.yield_real_time${postfix}.oil_prod_daily is '日产油';
            
            comment on column ${module_key}.yield_real_time${postfix}.gas_prod_daily is '日产气';
            
            comment on column ${module_key}.yield_real_time${postfix}.result2 is '二次诊断结果';
            
            comment on column ${module_key}.yield_real_time${postfix}.pump_efficiency is '泵效';
            
            comment on column ${module_key}.yield_real_time${postfix}.moisture_content is '含水率';
            
            comment on column ${module_key}.yield_real_time${postfix}.flag is '标记';
            
            comment on column ${module_key}.yield_real_time${postfix}.expand_coefficient is '膨胀系数';
            
            comment on column ${module_key}.yield_real_time${postfix}.theory_displacement is '理论排量';
            
            comment on column ${module_key}.yield_real_time${postfix}.left_stroke is '左冲程';
            
            comment on column ${module_key}.yield_real_time${postfix}.right_stroke is '右冲程';
            
            comment on column ${module_key}.yield_real_time${postfix}.actual_stroke is '实际冲程';
            
            comment on column ${module_key}.yield_real_time${postfix}.effect_stroke is '有效冲程';
            
            comment on column ${module_key}.yield_real_time${postfix}.stroke_loss is '冲程损失';
            
            comment on column ${module_key}.yield_real_time${postfix}.outflow_loss is '漏失损失';
            
            comment on column ${module_key}.yield_real_time${postfix}.liq_loss is '供液损失';
            
            comment on column ${module_key}.yield_real_time${postfix}.back_press is '回压';
            
            comment on column ${module_key}.yield_real_time${postfix}.oil_press is '油压';
            
            comment on column ${module_key}.yield_real_time${postfix}.sleeve_press is '套压';
            
            comment on column ${module_key}.yield_real_time${postfix}.water_prod_daily is '日产水';
            
            comment on column ${module_key}.yield_real_time${postfix}.refrence_work_diagram is '参考功图';
            
            comment on column ${module_key}.yield_real_time${postfix}.present_time is '以此功图生产此时间的产出量（0-24h）';
            
            comment on column ${module_key}.yield_real_time${postfix}.gas_liq_ratio is '气液比';
            
            comment on column ${module_key}.yield_real_time${postfix}.effect_stroke_ratio is '有效冲程比';
            
            comment on column ${module_key}.yield_real_time${postfix}.voltage is '电压';
            
            comment on column ${module_key}.yield_real_time${postfix}.ambient_temperature is '环境温度';
            
            comment on column ${module_key}.yield_real_time${postfix}.electricity is '电量';
            
            comment on column ${module_key}.yield_real_time${postfix}.signal_strength is '信号强度';
            
            comment on column ${module_key}.yield_real_time${postfix}.device_id is '设备号';
            
            comment on column ${module_key}.yield_real_time${postfix}.well_name is '井号名称';
            
            
            create index if not exists yield_real_time_module_key_index${postfix}
                on ${module_key}.yield_real_time${postfix} (module_key);
            
            create index if not exists yield_real_time_id_index${postfix}
                on ${module_key}.yield_real_time${postfix} (id);
            
            create index if not exists yield_real_time_pro_time_index${postfix}
                on ${module_key}.yield_real_time${postfix} (pro_time);